-- DROP STATEMENTS

DROP TRIGGER Trace.Trace_I;

DROP TRIGGER Trace.Trace_Fragment_I;

DROP TRIGGER Trace.Event_Id;

DROP TRIGGER Trace.Report_Id_Trigger;

ALTER TABLE Trace.LinkEvent DROP CONSTRAINT LinkEvent_Event_FK;

ALTER TABLE Trace.Error DROP CONSTRAINT Error_Message_FK;

ALTER TABLE Trace.Trace_Fragment DROP CONSTRAINT Trace_Fragment_Trace_FK;

ALTER TABLE Trace.Trace_Transfer DROP CONSTRAINT Trace_Transfer_Trace_FK;

ALTER TABLE Trace.Message DROP CONSTRAINT Message_MessageCategory_FK;

ALTER TABLE Trace.Error DROP CONSTRAINT Error_Event_FK;

ALTER TABLE Trace.Trace_Fragment DROP CONSTRAINT Trace_Fragment_LinkEvent_FK;

ALTER TABLE Trace.Trace_Transfer DROP CONSTRAINT Trace_Transfer_LinkEvent_FK;

ALTER TABLE Trace.InitialEvent DROP CONSTRAINT InitialEvent_Event_FK;

ALTER TABLE Trace.Trace DROP CONSTRAINT Trace_InitialEvent_FK;

ALTER TABLE Trace.MessageCategory DROP CONSTRAINT MessageCategory_PK;

ALTER TABLE Trace.Error DROP CONSTRAINT Error_PK;

ALTER TABLE Trace.Trace_Fragment DROP CONSTRAINT Trace_Fragment_PK;

ALTER TABLE Trace.Trace_Transfer DROP CONSTRAINT Trace_Transfer_PK;

ALTER TABLE Trace.Message DROP CONSTRAINT Message_PK;

ALTER TABLE Trace.InitialEvent DROP CONSTRAINT InitialEvent_PK;

ALTER TABLE Trace.Trace DROP CONSTRAINT Trace_PK;

ALTER TABLE Trace.Event DROP CONSTRAINT Event_PK;

ALTER TABLE Trace.LinkEvent DROP CONSTRAINT LinkEvent_PK;

DROP INDEX Trace.trace_epc_idx;

ALTER TABLE Trace.ContainerFullDisaggregations DROP CONSTRAINT ContainerFullDisaggregation_PK;

ALTER TABLE Trace.Containments DROP CONSTRAINT Trace_Containments_CK1;



DROP TABLE Trace.Event;

DROP TABLE Trace.Trace;

DROP TABLE Trace.Trace_Fragment;

DROP TABLE Trace.InitialEvent;

DROP TABLE Trace.Error;

DROP TABLE Trace.Message;

DROP TABLE Trace.MessageCategory;

DROP TABLE Trace.Trace_Transfer;

DROP TABLE Trace.LinkEvent;

DROP INDEX Trace.Containments_parent_epc_IDX;



DROP INDEX Trace.Containments_child_epc_IDX;



DROP SEQUENCE Trace.event_Id_Sequence;

DROP SEQUENCE Trace.Trace_Fragment_Sequence;

DROP SEQUENCE Trace.Trace_Sequence;

DROP SEQUENCE Trace.Trace_Transfer_Sequence;

-- report tables

DROP SEQUENCE Trace.Report_Id_Sequence;

-- ALTER TABLE Trace.Report DROP CONSTRAINT Report_SourceObject_FK;
ALTER TABLE Trace.ReportEpc DROP CONSTRAINT Report_Epc_FK;
ALTER TABLE Trace.Report DROP CONSTRAINT ErrorReport_PK;
    
DROP TABLE Trace.Report;
DROP TABLE Trace.ReportEpc;
DROP TABLE Trace.ReportInput;

-- DROP USER



DROP USER Trace cascade;

-- CREATE USER

CREATE USER Trace identified by trace;

-- GRANT PRIVILEGES TO TRACE

GRANT ALL PRIVILEGES TO Trace;

-- CREATE SEQUENCE

CREATE SEQUENCE Trace.event_Id_Sequence
	START WITH 1
	INCREMENT BY 1
	NOMAXVALUE;

CREATE SEQUENCE Trace.Trace_Sequence
	START WITH 1
	INCREMENT BY 1
	NOMAXVALUE;

CREATE SEQUENCE Trace.Trace_Fragment_Sequence
	START WITH 1
	INCREMENT BY 1
	NOMAXVALUE;

CREATE SEQUENCE Trace.Trace_Transfer_Sequence
	START WITH 1
	INCREMENT BY 1
	NOMAXVALUE;
	
CREATE SEQUENCE Trace.Report_Id_Sequence
    START WITH 1
    INCREMENT BY 1
    NOMAXVALUE;	
	

-- CREATE TABLE
-- if a tablespace is specified at the table level, then ${storage_opts} = TABLESPACE tablespace_x

CREATE TABLE Trace.Event (
		id_Event NUMBER NOT NULL,
		eventType NUMBER NOT NULL,
		eventTime TIMESTAMP(6) NOT NULL,
		eventSource VARCHAR2(100) NOT NULL
	) ${storage_opts};

CREATE TABLE Trace.InitialEvent (
		id_Event NUMBER NOT NULL,
		productId VARCHAR2(100)
	) ${storage_opts};

CREATE TABLE Trace.Trace (
		id_Trace NUMBER NOT NULL,
		id_initialEvent NUMBER,
		epc VARCHAR2(100) NOT NULL,
		status NUMBER NOT NULL
	) ${storage_opts};

CREATE TABLE Trace.Trace_Fragment (
		id_Trace NUMBER NOT NULL,
		id_Event NUMBER NOT NULL,
		sequence NUMBER NOT NULL
	) ${storage_opts};

CREATE TABLE Trace.LinkEvent (
		id_Event NUMBER NOT NULL,
		physicalSource VARCHAR2(100) NOT NULL,
		bizSource VARCHAR2(100) NOT NULL,
		physicalDestination VARCHAR2(100) NOT NULL,
		bizDestination VARCHAR2(100),
		contactId VARCHAR2(100)--,
		--eventepc VARCHAR2(100)
	) ${storage_opts};

CREATE TABLE Trace.Trace_Transfer (
		id_Trace NUMBER NOT NULL,
		id_Event NUMBER NOT NULL,
		sequence NUMBER NOT NULL
	) ${storage_opts};

CREATE TABLE Trace.MessageCategory (
		code CHAR(10) NOT NULL,
		title VARCHAR2(100)
	) ${storage_opts};
	
CREATE TABLE Trace.Message (
		code CHAR(10) NOT NULL,
		category CHAR(10) NOT NULL,
		title VARCHAR2(100)
	) ${storage_opts};

CREATE TABLE Trace.Error (
		id_Event NUMBER NOT NULL,
		code CHAR(10) NOT NULL,
		args VARCHAR2(1000)
	) ${storage_opts};

CREATE TABLE Trace.Containments (
		parent_epc VARCHAR(100) NOT NULL,
		child_epc VARCHAR(100) NOT NULL,
		child_is_container CHAR(1) DEFAULT 'f' NOT NULL,
		aggregation_time TIMESTAMP(6),
		disaggregation_time TIMESTAMP(6)
	) ${storage_opts};

	
CREATE TABLE Trace.ContainerFullDisaggregations (
		parent_epc VARCHAR(100) NOT NULL,
		disaggregation_time TIMESTAMP(6) NOT NULL
	) ${storage_opts};
	
	
-- Report

CREATE TABLE TRACE.REPORT (
        ID_REPORT NUMBER NOT NULL,
        ID_SRCOBJECT VARCHAR(256) NOT NULL,
        SRCOPERATION VARCHAR(256) NOT NULL,
        ERRORTEXT VARCHAR(2048) NOT NULL,
        ERRORDETAIL VARCHAR(4000),
        ERRORTIME TIMESTAMP(6) NOT NULL
    ) ${storage_opts};

CREATE TABLE TRACE.REPORTEPC (
        ID_REPORT NUMBER NOT NULL,
        EPC VARCHAR(256) NOT NULL
    ) ${storage_opts};

CREATE TABLE TRACE.REPORTINPUT (
        ID_SRCOBJECT VARCHAR(256) NOT NULL,
        SRCOBJECT CLOB
    ) ${storage_opts};


ALTER TABLE Trace.Event ADD CONSTRAINT Event_PK PRIMARY KEY (id_Event);

ALTER TABLE Trace.InitialEvent ADD CONSTRAINT InitialEvent_PK PRIMARY KEY (id_Event);

ALTER TABLE Trace.Trace ADD CONSTRAINT Trace_PK PRIMARY KEY (id_Trace);

ALTER TABLE Trace.Trace_Fragment ADD CONSTRAINT Trace_Fragment_PK PRIMARY KEY (id_Trace, id_Event);

ALTER TABLE Trace.LinkEvent ADD CONSTRAINT LinkEvent_PK PRIMARY KEY (id_Event);

ALTER TABLE Trace.Trace_Transfer ADD CONSTRAINT Trace_Transfer_PK PRIMARY KEY (id_Trace, id_Event);

ALTER TABLE Trace.MessageCategory ADD CONSTRAINT MessageCategory_PK PRIMARY KEY (code);

ALTER TABLE Trace.Message ADD CONSTRAINT Message_PK PRIMARY KEY (code);

ALTER TABLE Trace.Error ADD CONSTRAINT Error_PK PRIMARY KEY (id_Event, code);

ALTER TABLE Trace.Containments ADD CONSTRAINT Trace_Containments_CK1 CHECK (child_is_container IN ('t', 'f'));

ALTER TABLE Trace.ContainerFullDisaggregations ADD CONSTRAINT ContainerFullDisaggregation_PK PRIMARY KEY (parent_epc, disaggregation_time);

ALTER TABLE Trace.InitialEvent ADD CONSTRAINT InitialEvent_Event_FK FOREIGN KEY (id_Event)
	REFERENCES Trace.Event (id_Event)
	ON DELETE CASCADE;

ALTER TABLE Trace.Trace ADD CONSTRAINT Trace_InitialEvent_FK FOREIGN KEY (id_initialEvent)
	REFERENCES Trace.InitialEvent (id_Event)
	ON DELETE CASCADE;

ALTER TABLE Trace.Trace_Fragment ADD CONSTRAINT Trace_Fragment_Trace_FK FOREIGN KEY (id_Trace)
	REFERENCES Trace.Trace (id_Trace)
	ON DELETE CASCADE;

ALTER TABLE Trace.Trace_Fragment ADD CONSTRAINT Trace_Fragment_LinkEvent_FK FOREIGN KEY (id_Event)
	REFERENCES Trace.LinkEvent (id_Event)
	ON DELETE CASCADE;

ALTER TABLE Trace.LinkEvent ADD CONSTRAINT LinkEvent_Event_FK FOREIGN KEY (id_Event)
	REFERENCES Trace.Event (id_Event)
	ON DELETE CASCADE;

ALTER TABLE Trace.Trace_Transfer ADD CONSTRAINT Trace_Transfer_Trace_FK FOREIGN KEY (id_Trace)
	REFERENCES Trace.Trace (id_Trace)
	ON DELETE CASCADE;

ALTER TABLE Trace.Trace_Transfer ADD CONSTRAINT Trace_Transfer_LinkEvent_FK FOREIGN KEY (id_Event)
	REFERENCES Trace.LinkEvent (id_Event)
	ON DELETE CASCADE;

ALTER TABLE Trace.Message ADD CONSTRAINT Message_MessageCategory_FK FOREIGN KEY (category)
	REFERENCES Trace.MessageCategory (code)
	ON DELETE CASCADE;

ALTER TABLE Trace.Error ADD CONSTRAINT Error_Message_FK FOREIGN KEY (code)
	REFERENCES Trace.Message (code)
	ON DELETE CASCADE;

ALTER TABLE Trace.Error ADD CONSTRAINT Error_Event_FK FOREIGN KEY (id_Event)
	REFERENCES Trace.Event (id_Event)
	ON DELETE CASCADE;
	
-- Report

ALTER TABLE TRACE.REPORT ADD CONSTRAINT ERRORREPORT_PK PRIMARY KEY (ID_REPORT);

--ALTER TABLE TRACE.REPORT ADD CONSTRAINT FOREIGN KEY (ID_SRCOBJECT)
--    REFERENCES TRACE.REPORTINPUT (ID_SRCOBJECT) ON DELETE CASCADE
--    CONSTRAINT REPORT_SOURCEOBJECT_FK;

ALTER TABLE TRACE.REPORTEPC ADD CONSTRAINT REPORT_EPC_FK FOREIGN KEY (ID_REPORT) 
    REFERENCES TRACE.REPORT (ID_REPORT) ON DELETE CASCADE;

-- CREATE TRIGGER

CREATE TRIGGER Trace.Event_Id
BEFORE INSERT ON Trace.Event
FOR EACH ROW
BEGIN
SELECT event_Id_Sequence.nextval into :new.id_Event from dual;
END;
/

CREATE TRIGGER Trace.Trace_I
BEFORE INSERT ON Trace.Trace
FOR EACH ROW
BEGIN
SELECT Trace_Sequence.nextval into :new.id_Trace from dual;
END;
/

CREATE TRIGGER Trace.Trace_Fragment_I
BEFORE INSERT ON Trace.Trace_Fragment
FOR EACH ROW
BEGIN
SELECT Trace_Fragment_Sequence.nextval into :new.id_Trace from dual;
END;
/
    
CREATE TRIGGER Trace.Report_Id_Trigger
BEFORE INSERT ON Trace.Report
FOR EACH ROW
BEGIN
SELECT Report_Id_Sequence.nextval into :new.id_Report from dual;
END;
/    

CREATE INDEX Trace.trace_epc_idx ON Trace.Trace(epc);	


--CREATE TRIGGER Trace.Trace_Transfer_I 

--	BEFORE INSERT ON Trace.Trace_Transfer

--	FOR EACH ROW

--BEGIN

-- SELECT Trace_Transfer_Sequence.nextval into :new.id_Trace from dual; 

--END;

--/

CREATE INDEX Trace.Containments_parent_epc_IDX on Trace.Containments (parent_epc);

CREATE INDEX Trace.Containments_child_epc_IDX on Trace.Containments (child_epc);

commit;
