#!/bin/ksh
#
# Licensed Materials - Property of IBM
#
# Governed under the terms of the International
# License Agreement for Non-Warranted Sample Code.
#
# 5724-O98 (C) COPYRIGHT International Business Machines Corp. 2006, 2012
# All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
#
# callWebService.sh - Calls the webservice as specified in the input parameters to the script
# By default, if no parameters are passed it will run a subscription query. 
#
# Usage: callWebService.sh [-was_admin_user=<value>] [-was_admin_password=<value>] [-soap=<absolute path of xml file containing soap>] [-path=<Relative path of WebService to which the SOAP has to be submitted>]
# Example1: callWebService.sh // This will run the subscription query
# Example2: callWebService.sh -soap=$PEDIGREE_HOME/etc/PEDIGREE_ImportPolicies.xml -path=com.ibm.ts.web/services/SecurityRegistryPort
#############################################################################

SCRIPT_DIR=`dirname ${0}`
if [ -f ${SCRIPT_DIR}/pedigree-env.sh ]; then
	. ${SCRIPT_DIR}/pedigree-env.sh
else
	# "$0 : File not found ${SCRIPT_DIR}/pedigree-env.sh"
	exit -1
fi

# print usage
usage(){
pedigree-get-message.sh TSIN02145I
#echo "Usage: callWebServices.sh [-was_admin_user=<value>] [-was_admin_password=<value>] [-soap=<absolute path of xml file containing soap>] [-path=<Relative path of WebService to which the SOAP has to be submitted>]"
pedigree-get-message.sh TSIN02146I
#echo "Example1: callWebServices.sh // This will run the subscription query"
pedigree-get-message.sh TSIN02147I
#echo "Example2: callWebServices.sh -soap=$PEDIGREE_HOME/etc/PEDIGREE_ImportPolicies.xml -path=com.ibm.ts.web/services/SecurityRegistryPort"
}

PATHTOFILE=ts/engine/services/EPCglobalEPCISService
SOAP=$PEDIGREE_HOME/etc/sub.capture.xml
#PATHTOFILE=com.ibm.ts.web/services/SecurityRegistryPort
#SOAP=$PEDIGREE_HOME/etc/PEDIGREE_ImportPolicies.xml

for item in $*
   do
     if [ `expr match "$item" '-was_admin_user'` != 0 ];then
          was_admin_user=`echo ${item#-was_admin_user=}`
     elif [ `expr match "$item" '-was_admin_password'` != 0 ];then
          was_admin_password=`echo ${item#-was_admin_password=}`
     elif [ `expr match "$item" '-soap'` != 0 ];then
          SOAP=`echo ${item#-soap=}`
     elif [ `expr match "$item" '-path'` != 0 ];then
          PATHTOFILE=`echo ${item#-path=}`
     elif [ `expr match "$item" '-output'` != 0 ];then
          OUTPUT=`echo ${item#-output=}`
     elif [ `expr match "$item" '-help'` != 0 ];then
         usage
         exit 1
     else
         usage
         exit 1
     fi
done

WAS_PORT_NO=$RFIDIC_PORT
URL=$RFIDIC_HOST:$WAS_PORT_NO/$PATHTOFILE
VERSION=`wget -V | grep Wget`
echo $VERSION
if [ "$VERSION" = "GNU Wget 1.9.1" ]
then
	if [ -n "$was_admin_user" -a -n "$was_admin_password" ]
	then
		wget --http-user=$was_admin_user --http-passwd=$was_admin_password --post-file=$SOAP --header=SOAPAction:unused --header='Content-Type: text/xml; charset=utf-8' https://$URL
	else
		wget --post-file=$SOAP --header=SOAPAction:unused --header='Content-Type: text/xml; charset=utf-8' http://$URL
	fi
else
	if [ -n "$was_admin_user" -a -n "$was_admin_password" ]
	then
		wget --no-check-certificate --http-user=$was_admin_user --http-password=$was_admin_password --post-file=$SOAP --header=SOAPAction:unused --header='Content-Type: text/xml; charset=utf-8' https://$URL
	else
		wget --no-check-certificate --post-file=$SOAP --header=SOAPAction:unused --header='Content-Type: text/xml; charset=utf-8' http://$URL
	fi
fi
returnCode=$?
if [ $returnCode -eq 0 ]
then
	RESULT=`basename $PATHTOFILE`	
	if [ "$OUTPUT" != "" ]
	then
		xmllint -format $RESULT > $OUTPUT
	fi
	rm $RESULT
else
	echo $0 encountered an error processing $SOAP on $URL
fi
exit $returnCode
