#!/bin/ksh
#
# Licensed Materials - Property of IBM
#
# Governed under the terms of the International
# License Agreement for Non-Warranted Sample Code.
#
# 5724-O98 (C) COPYRIGHT International Business Machines Corp. 2006, 2012
# All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
#
# cleanupSample.sh - cleans up the data from the pedigree tables
# This should be used only when setupSample.sh is run on an empty database.
#
# Usage: cleanupSample.sh
#############################################################################

# ---------------------------------------------------------------------
# Main
#
# setup solution environment
#

usage()
{
  echo "Usage: cleanupSample.sh"
  echo "       [-dba_user]"
  pedigree-get-message.sh TSIN01259I
  echo "       [-dba_password]"
  pedigree-get-message.sh TSIN01260I
  echo "       [-was_admin_user=<User name used for WAS administration>]"
  pedigree-get-message.sh TSIN01160I
  echo "	   [-was_admin_password=<Password of the user>]"
  pedigree-get-message.sh TSIN01161I
  echo "	   [-was_runas_user=<User for running WAS if different from the $RFIDIC_USER>]"
  pedigree-get-message.sh TSIN01158I $RFIDIC_USER
  echo "	   [-was_admin_group=<the group to which was_admin_user belongs to>]"
  pedigree-get-message.sh TSIN01258I
  echo "	   [-DB_TABLE_SPACE=<tablespace name if you want the tables created here>]"
  echo "	   [-help  print the usage]"
  echo "  	   none sets up sample and prompts for dba_user and password if required"
  
}

continueOrExit(){
	#pedigree-get-message.sh -noid TSIN01260I
	#echo "Are you sure you want to continue?"
	pedigree-get-message.sh TSIN01220I
	#echo "Press 1 to continue"
	pedigree-get-message.sh TSIN01321I
	#echo "Press 2 to exit the cleanup"
	read ans
	if [ "$ans" = "1" ];then
		return 1
	elif [ "$ans" = "2" ];then
		exit 1		
	else
		pedigree-get-message.sh TSIN01011E
		#echo "Invalid input. Try again"
		exit_confirm
	fi
}

promptDBAUser(){
	dbToPrompt=$1
	if [ -z "$dba_user" ];then
		pedigree-get-message.sh TSIN01017I
		#echo "Enter the dba user for the database $dbToPrompt"
		read dba_user
	fi
	if [ -n "$dba_user" -a -z "$dba_password" ];then
		pedigree-get-message.sh TSIN01018I $dba_user
		#echo "Enter the password for the user $dba_user:"
		stty -echo
		read dba_password
		stty echo
	fi
	if [ "$dbToPrompt" = "TraceabilityServer" ];then
		ts_dba_user=$dba_user
		ts_dba_password=$dba_password
	else
		ped_dba_user=$dba_user
		ped_dba_password=$dba_password
	fi
}

reinstallDocPedSchema(){
		# Recreate the solution schemas in pedigree
		pedigree-get-message.sh TSIN02041I
		#echo "ReConfiguring the database for document pedigree..."
		getDBConfig
		#Replace the TableSpace value in the SQL scripts if specified else replace the TABLESPACE clause itself
		searchStr[0]='${storage_opts}'
		if [ -z "$DB_TABLE_SPACE" ];then
			replaceStr[0]=""
		else
			if [ "$DB_TYPE" = "ORACLE" ];then
				replaceStr[0]=" TABLESPACE $DB_TABLE_SPACE "
			else
				replaceStr[0]=" in $DB_TABLE_SPACE "
			fi
		fi
		asciiUpdate "$docped_file" "$searchStr" "$replaceStr"
		${WAS_HOME}/java/bin/java -classpath $cp com.ibm.rfidic.pedigree.install.syscheck.SQLFileExecutor ${JDBC} ${driverClassName} ${dba_user} ${dba_password} ${docped_file}
		ret=$?
		if [ $ret -ne 0 ];then
			pedigree-get-message.sh TSIN02042E
			#echo_msg "Configuration of database for document pedigree not successful."
			retStatus=1
		fi
		echo_msg PEDI06807I
		if [ "$dba_user" = "$DBMS_ADMIN_USER" ];then
			echo_msg "DBA User entered is the same as database user. Hence not granting privileges"
		else
			searchStr[0]='${non_dba_user}'
			replaceStr[0]="$DBMS_ADMIN_USER"
			asciiUpdate "$grant_docPed_priv_file" "$searchStr" "$replaceStr"
			${WAS_HOME}/java/bin/java -classpath $cp com.ibm.rfidic.pedigree.install.syscheck.SQLFileExecutor ${JDBC} ${driverClassName} ${dba_user} ${dba_password} ${grant_docPed_priv_file}
			ret=$?
			if [ $ret -ne 0 ];then
				pedigree-get-message.sh TSIN02044E
				#echo_msg "Configuration of pedigree database for non-DBA - docPed-rights not successful."
				retStatus=1
			fi
		fi
		return $retStatus
}

reinstallEventSchema() {
		retStatus=0
		# Recreate the solution schemas in pedigree
		pedigree-get-message.sh TSIN02052I
		#echo "Configuring the database for event pedigree..."
		getDBConfig
		#Replace the TableSpace value in the SQL scripts if specified else replace the TABLESPACE clause itself
		searchStr[0]='${storage_opts}'
		if [ -z "$DB_TABLE_SPACE" ];then
			replaceStr[0]=""
		else
			if [ "$DB_TYPE" = "ORACLE" ];then
				replaceStr[0]=" TABLESPACE $DB_TABLE_SPACE "
			else
				replaceStr[0]=" in $DB_TABLE_SPACE "
			fi
		fi
		asciiUpdate "$trace_file" "$searchStr" "$replaceStr"
		${WAS_HOME}/java/bin/java -classpath $cp com.ibm.rfidic.pedigree.install.syscheck.SQLFileExecutor ${JDBC} ${driverClassName} ${dba_user} ${dba_password} ${trace_file} 
		ret=$?
		if [ $ret -ne 0 ];then
			pedigree-get-message.sh TSIN02053E
			#echo_msg "Configuration of database for event pedigree not successful."
			retStatus=1
		fi
		if [ "$dba_user" = "$DBMS_ADMIN_USER" ];then
			echo_msg "DBA User entered is the same as database user. Hence not granting privileges (trace)"
		else
			searchStr[0]='${non_dba_user}'
			replaceStr[0]="$DBMS_ADMIN_USER"
			asciiUpdate "$grant_trace_priv_file" "$searchStr" "$replaceStr"
			${WAS_HOME}/java/bin/java -classpath $cp com.ibm.rfidic.pedigree.install.syscheck.SQLFileExecutor ${JDBC} ${driverClassName} ${dba_user} ${dba_password} ${grant_trace_priv_file}
			ret=$?
			if [ $ret -ne 0 ];then
				pedigree-get-message.sh TSIN02054I
				#echo_msg "Configuration of pedigree database for non-DBA rights - trace- not successful."
				retStatus=1
			fi
		fi
		${WAS_HOME}/java/bin/java -classpath $cp com.ibm.rfidic.pedigree.install.syscheck.SQLFileExecutor ${JDBC} ${driverClassName} ${dba_user} ${dba_password} ${msg_file} 
		ret=$?
		if [ $ret -ne 0 ];then
			pedigree-get-message.sh TSIN02053E
			#echo_msg "Configuration of database for event pedigree not successful."
			retStatus=1
		fi
#		${WAS_HOME}/java/bin/java -classpath $cp com.ibm.rfidic.pedigree.install.syscheck.SQLFileExecutor ${JDBC} ${driverClassName} ${dba_user} ${dba_password} ${file} 
#		ret=$?
#		if [ $ret -ne 0 ];then
			pedigree-get-message.sh TSIN02164E
#			#echo_msg "Configuration of database for Audit Views of pedigree not successful."
#			retStatus=1
#		fi
		return $retStatus
}

unset DBMS_DB_NAME;unset DBMS_HOME;unset DBMS_ADMIN_USER;unset DBMS_ADMIN_PWD;unset DB_TYPE;unset DBMS_PORT;unset DBMS_SERVER
unset WAS_HOME;unset PROFILENAME;unset CELLNAME;unset NODENAME;unset SERVERNAME
unset MQ_HOME;unset QUEUE_MANAGER;unset MQ_LSR_PORT;unset MQ_USER
unset RFIDIC_HOME;unset RFIDIC_USER

SCRIPT_DIR=`dirname ${0}`
echo "Going to execute "
if [ -f ${SCRIPT_DIR}/pedigree-env.sh ]; then
	. ${SCRIPT_DIR}/pedigree-env.sh
else
	# "$0 : File not found ${SCRIPT_DIR}/pedigree-env.sh"
	exit -1
fi

for item in $*
do
	if [ `expr match "$item" '-dba_user'` != 0 ];then
              dba_user=`echo ${item#-dba_user=}`
	elif [ `expr match "$item" '-dba_password'` != 0 ];then
              dba_password=`echo ${item#-dba_password=}`    
	elif [ `expr match "$item" '-dba_password'` != 0 ];then
              dba_password=`echo ${item#-dba_password=}`    
	elif [ `expr match "$item" '-was_admin_user'` != 0 ];then
              was_admin_user=`echo ${item#-was_admin_user=}`    
	elif [ `expr match "$item" '-was_admin_password'` != 0 ];then
              was_admin_password=`echo ${item#-was_admin_password=}`    
	elif [ `expr match "$item" '-was_admin_group'` != 0 ];then
              was_admin_group=`echo ${item#-was_admin_group=}`    
   	elif [ `expr match "$item" '-was_runas_user'` != 0 ];then
      		was_runas_user=`echo ${item#-was_runas_user=}`
   	elif [ `expr match "$item" '-DB_TABLE_SPACE'` != 0 ];then
      		DB_TABLE_SPACE=`echo ${item#-DB_TABLE_SPACE=}`
	else
			usage
			exit
    fi
done

pedigree-get-message.sh TSIN02165W
#echo "*** Warning *** This script will recreate the pedigree solution schemas. "
pedigree-get-message.sh TSIN02166W
#echo "It will delete all data setup on pedigree"
continueOrExit

LOG=${RFIDIC_SOLDIR}/bin/cleanupSample.log
if [ -f "$LOG" ];then
	index=0
	while [ "$index" -lt "10" ]
        do
            index=`expr $index + 1`
        	LOG=${SCRIPT_DIR}/cleanupSample-$index.log
			if [ -f "$LOG" ];then
				echo " "
	        else
			    index=100
			fi
        done
	if [ -f "$LOG" ];then
		echo "Please delete or archive all old log files and then continue"
		pause
	fi
fi

if [ -n "$was_admin_user" -a -n "$was_admin_password" ];then
	credentials="-was_admin_user=$was_admin_user -was_admin_password=$was_admin_password"
	wsadmin_creds="-conntype SOAP -user $was_admin_user -password $was_admin_password"
fi
if [ -n "$was_runas_user" ];then
	was_runas="-was_runas_user=$was_runas_user"
fi

${RFIDIC_HOME}/bin/stopTS.sh -components=was,capture $credentials >> $LOG

### Deploying Metadata ###
pedigree-get-message.sh TSIN01112I
#echo "Deploying Pedigree Metadata"
if  [ "$DB_TYPE" = "INFORMIX" ];then
	run_command ${TS_HOME}/bin/deployMetadata.sh -force_drop_tables -force_stop_was $credentials >> $LOG
else
	promptDBAUser TraceabilityServer
	run_command ${TS_HOME}/bin/deployMetadata.sh -dba_user=$ts_dba_user -dba_password=$ts_dba_password -force_drop_tables $credentials  >> $LOG
fi

# Recreate the solution schemas in pedigree
getDBConfig
promptDBAUser Pedigree

reinstallDocPedSchema >> $LOG
docCode=$?
reinstallEventSchema >> $LOG
eventCode=$?
${TS_HOME}/bin/startTS.sh -components=was,capture $credentials $was_runas >> $LOG
if [ "$docCode" = "0" -a "$eventCode" = "0" ];then
	echo_msg "---------------------------------------------------"
	pedigree-get-message.sh TSIN02167I
	#echo_msg "cleanup was done correctly."
	echo_msg "---------------------------------------------------"
else
	echo_msg "---------------------------------------------------"
	pedigree-get-message.sh TSIN02168E
	#echo_msg "Some Cleanup is not successful. Please check logs"
	echo_msg "---------------------------------------------------"
fi

