#!/bin/sh
#############################################################################
## Licensed Materials - Property of IBM
##
## Governed under the terms of the International
## License Agreement for Non-Warranted Sample Code.
##
## (C) COPYRIGHT International Business Machines Corp. 2008, 2012
## All Rights Reserved.
##
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##
##   Title:	pedigree-env.sh
##   Description: Sets the environment for other pedigree config scripts to use
##		
##
#############################################################################
###This file is forced to be included into the Delta build for IFIX-02, as the ascii-update in inst-upgr-pen-env.sh updates only the default values.  

unset DBMS_DB_NAME;unset DBMS_HOME;unset DBMS_ADMIN_USER;unset DBMS_ADMIN_PWD;unset DB_TYPE;unset DBMS_PORT;unset DBMS_SERVER;unset DBMS_ALIAS
unset WAS_HOME;unset PROFILENAME;unset CELLNAME;unset NODENAME;unset SERVERNAME
unset MQ_HOME;unset QUEUE_MANAGER;unset MQ_LSR_PORT;unset MQ_USER;unset MQ_USER_PASSWORD
unset ORACLE_GROUP;unset ORACLE_USER;unset ORACLE_HOME;unset ORACLE_JDBC_URL
unset DB2_INSTANCE;unset DB2_GROUP;unset DB2_SERVER

CP="/bin/cp"
RM="/bin/rm -f"
ECHO="echo"
AWK="awk -F ".""
AWK_EQUAL="awk -F "=""
AWK_COLON="awk -F ":""
AWK_BRACE1="awk -F "\>""
AWK_BRACE2="awk -F "\<""
RFIDIC_PROFILE=".profile"
TAIL="tail -n8"
USERID="id"
ID=`id`

PLATFORM=`/bin/uname`
case $PLATFORM in
	AIX)
		HOSTNAME=`hostname -s`
		HOSTNAMEFULL=`hostname`
		;;
	Linux)
		ECHO="echo -e"
		HOSTNAME=`hostname -s`
		RFIDIC_PROFILE=".bash_profile"
		HOSTNAMEFULL=`hostname -f`
		CP="/bin/cp --reply=yes"
		;;
	SunOS)
		AWK="awk -F."
		AWK_EQUAL="awk -F="
		AWK_COLON="awk -F:"
		AWK_BRACE1="awk -F>"
		AWK_BRACE2="awk -F<"
		HOSTNAME=`hostname`
		release=`uname -r`
		if [ "$release" = "5.10" ];then
			HOSTNAMEFULL=`/usr/sbin/check-hostname | awk '{print($7)}'`
		else
			HOSTNAMEFULL=`/usr/lib/mail/sh/check-hostname | awk '{print($7)}'`
		fi
		TAIL="tail -8"
		USERID="id -a"
		ID=`id -a`
		;;
esac


CURRENT_USER=`expr "$ID" : ".*uid=[0-9]*(\([^)]*\)*"`
CURRENT_GROUP=`expr "$ID" : ".*gid=[0-9]*(\([^)]*\)*"`

# get CELLNAME and NODENAME from WAS installation. This might override defaults.
getActualWASConfig () {

   if [ ! -n "$PROFILENAME" ]; then
	  PROFILENAME=AppSrv01
   fi
   
   WAS_CFG=${WAS_HOME}/profiles/${PROFILENAME}/config/cells
   echo PROFILENAME = $PROFILENAME
   echo CELLNAME = $CELLNAME
   echo NODENAME = $NODENAME
   echo SERVERNAME = $SERVERNAME
   if [ ! -d "$WAS_CFG" ];then
	if [ `ls ${WAS_HOME}/profiles | wc -w` = "1" ]; then
		PROFILENAME=`ls ${WAS_HOME}/profiles`
        	WAS_CFG=${WAS_HOME}/profiles/${PROFILENAME}/config/cells
		echo PROFILENAME = $PROFILENAME
   	else
		echo "The $PROFILENAME WebSphere Application Server (WAS) profile was not found."
    		#rfidic-get-message.sh RFID05035E "$PROFILENAME"
		return 1
	fi
   fi
	  if [ ! -d $WAS_CFG/$CELLNAME ]; then
	  if [ `ls ${WAS_CFG}| wc -w` = "1" ]; then
		CELLNAME=`ls ${WAS_CFG}`
		echo CELLNAME = $CELLNAME
	  else
		echo "The tool cannot determine which WebSphere Application Server (WAS) cell to use."
        	#rfidic-get-message.sh RFID05029E
		return 1
	  fi
	fi
	if [ ! -d $WAS_CFG/$CELLNAME/nodes/$NODENAME ];then
  	   if [ `ls ${WAS_CFG}/${CELLNAME}/nodes | wc -w` = "1" ]; then
		  NODENAME=`ls ${WAS_CFG}/${CELLNAME}/nodes`
	   echo "The NODENAME variable was reset to $NODENAME."
          #rfidic-get-message.sh RFID05031I "$NODENAME"
                
 	   else
		echo "The tool cannot determine which WebSphere Application Server (WAS) node to use."
          	#rfidic-get-message.sh RFID05032E
		  return 1
	   fi
	fi
	if [ ! -d $WAS_CFG/$CELLNAME/nodes/$NODENAME/servers/$SERVERNAME ]; then
	   if [ `ls ${WAS_CFG}/${CELLNAME}/nodes/${NODENAME}/servers | wc -w` = "1" ]; then
		  SERVERNAME=`ls ${WAS_CFG}/${CELLNAME}/nodes/${NODENAME}/servers`
          	echo "The SERVERNAME variable was reset to $SERVERNAME."
		#rfidic-get-message.sh RFID05033I "$SERVERNAME"
	   else
		echo "The tool cannot determine which WebSphere Application Server (WAS) server to use."
          #rfidic-get-message.sh RFID05034E
		  return 1
	   fi
	fi
}


getDBConfig(){
unset JDBC
unset cp
unset driverClassName
unset msg_file
unset trace_file
unset docped_file
unset grant_docPed_priv_file
unset grant_trace_priv_file
unset revoke_priv_file
cp=${RFIDIC_SOLDIR}/lib/com.ibm.rfidic.pedigree.install.syscheck.jar:${RFIDIC_SOLDIR}/lib/commons-dbutils-1.1.jar

case "$DB_TYPE" in
DB2)
	driverClassName="com.ibm.db2.jcc.DB2Driver"
	cp=$cp:${PED_DBMS_LIB_HOME}/db2jcc.jar:${PED_DBMS_LIB_HOME}/db2jcc_license_cu.jar
	JDBC="jdbc:db2://${PEDIGREE_DB_HOST}:${DBMS_PORT}/${DBMS_DB_NAME}"
	msg_file="${RFIDIC_SOLDIR}/bin/DB2/insertTraceMessages.sql"
	file="${RFIDIC_SOLDIR}/bin/DB2/recreateAuditviews.sql"
	trace_file="${RFIDIC_SOLDIR}/bin/DB2/recreateTraceSchema.sql"
	docped_file="${RFIDIC_SOLDIR}/bin/DB2/create_docPedigreeSchema.sql"
	grant_docPed_priv_file="${RFIDIC_SOLDIR}/bin/DB2/grant_UserPrivileges_docPed.sql"
	grant_trace_priv_file="${RFIDIC_SOLDIR}/bin/DB2/grant_UserPrivileges_trace.sql"
	revoke_priv_file="${RFIDIC_SOLDIR}/bin/DB2/revoke_UserPrivileges.sql"
	;;
ORACLE)
	driverClassName="oracle.jdbc.OracleDriver"
	cp=$cp:${PED_DBMS_LIB_HOME}/ojdbc6.jar
	JDBC="$ORACLE_JDBC_URL"
	msg_file="${RFIDIC_SOLDIR}/bin/Oracle/insertTraceMessages.sql"
	file="${RFIDIC_SOLDIR}/bin/Oracle/recreateAuditviews.sql"
	trace_file="${RFIDIC_SOLDIR}/bin/Oracle/recreateTraceSchema.sql"
	docped_file="${RFIDIC_SOLDIR}/bin/Oracle/create_docPedigreeSchema.sql"
	grant_docPed_priv_file="${RFIDIC_SOLDIR}/bin/Oracle/grant_UserPrivileges_docPed.sql"
	grant_trace_priv_file="${RFIDIC_SOLDIR}/bin/Oracle/grant_UserPrivileges_trace.sql"
	revoke_priv_file="${RFIDIC_SOLDIR}/bin/Oracle/revoke_UserPrivileges.sql"
	;;
*)
	echo_message PEDI06806I
	;;
esac

export cp
export JDBC
export driverClassName
export msg_file
export trace_file
export docped_file
export grant_docPed_priv_file
export grant_trace_priv_file
export revoke_priv_file
}


determineIP()
{
	if [ "$PLATFORM" = "AIX" ];then
		var1=`ifconfig -l | sed 's,lo.*,,g' | wc -w`
		if [ "$var1" -gt "1" ];then
			IP="127.0.0.1"
			echo "Multiple network interfaces were detected. IP has been set to 127.0.0.1."
			#rfidic-get-message.sh RFID05147W
		else
			IP=`host -n -t A $HOSTNAME | awk '{print($4)}'`
		fi
	elif [ "$PLATFORM" = "Linux" ];then
		var1=`netstat -i | grep -v "lo" | wc -l`
		# Ignoring first two lines (header)
		if [ "$var1" -gt "3" ];then
			IP="127.0.0.1"
			echo "Multiple network interfaces were detected. IP has been set to 127.0.0.1."
			#rfidic-get-message.sh RFID05147W
		else
			IP=`hostname -i | sed "s/ //"`
		fi
	elif [ "$PLATFORM" = "SunOS" ];then
			var1=`netstat -i | grep -v "lo" | wc -l`
			# Ignoring first two lines (header)
			if [ "$var1" -gt "3" ];then
				IP="127.0.0.1"
				echo "Multiple network interfaces were detected. IP has been set to 127.0.0.1."
				#rfidic-get-message.sh RFID05147W
			else
				IP=`getent hosts $HOSTNAME | awk '{print($1)}'`
			fi
	fi
}

distributed(){
host=$1
if [ "$host" = "$HOSTNAME" -o "$host" = "$HOSTNAMEFULL" -o "$host" = "$IP" ];then
	return 0
else 
	return 1
fi
}

startOracle(){
   echo "========================================="
   if [ -d "$DBMS_HOME" ]
   then
     #echo "Starting Oracle..." 
     echo_message PEDI06818I
     $DBMS_HOME/bin/dbstart
else
     #echo "Error while Starting Oracle because RBDMS was not found in $DBMS_HOME" 
     echo_message PEDI06819E "$DBMS_HOME"
     exit 1
fi
}

startDB2(){
   echo "========================================="
   if [ -d "$DBMS_HOME" ]
   then
     	#echo "Starting DB2..." 
     	echo_message PEDI06820I
     	/home/$DB2_INSTANCE/sqllib/adm/db2start
   else
     	#echo "Error while Starting DB2 because RBDMS was not found in $DBMS_HOME" 
     	echo_message PEDI06821E "$DBMS_HOME"
     	exit 1
   fi
}

stopOracle(){
	echo "========================================="
if [ -d "$DBMS_HOME" ];then
	#echo "Stopping Oracle..."
	echo_message PEDI06824I
    $DBMS_HOME/bin/dbshut
else
	#echo "Oracle could not be stopped as the RDBMS was not found under, $DBMS_HOME"
	echo_message PEDI06825I "$DBMS_HOME"
	exit 1
fi
}

stopDB2(){
	echo "========================================="
if [ -d "$DBMS_HOME" ]
then
	#echo "Stopping DB2..."
	echo_message PEDI06826I
	/home/$DB2_INSTANCE/sqllib/adm/db2stop force
else
	echo_message PEDI06827I "$DBMS_HOME"
	exit 1
fi
}

NO_ARGS=0
E_ENVERROR=10
E_OPTERROR=11
E_COPYERROR=12
E_RFIDIC=13
E_DBERROR=14
E_FILEERROR=15


#
# Sets platform-dependent variables.
#
checkPlatform()
{
	CP="/bin/cp"
	RM="/bin/rm -f"
	AWK_EQUAL="awk -F "=""
	PLATFORM=`/bin/uname`
	case $PLATFORM in
		AIX)
			HOSTNAME=`hostname -s`
			HOSTNAMEFULL=`hostname`
			;;
		Linux)
			HOSTNAME=`hostname -s`
			HOSTNAMEFULL=`hostname -f`
			CP="/bin/cp --reply=yes"
			if [ -f "/etc/redhat-release" ];then
				release=`cat /etc/redhat-release | awk '{print($7)}' | ${AWK} '{print($1)}'`
				if [ "$release" = "5" ];then
					CP="/bin/cp -f"
				fi
			elif [ -f "/etc/SuSE-release" ];then
				release=`cat /etc/SuSE-release | grep "VERSION" | awk '{print($3)}'`
				if [ "$release" = "10" ];then
					CP="/bin/cp -f"
				fi
			fi
			;;
		SunOS)
			AWK_EQUAL="awk -F="
			HOSTNAME=`hostname`
			HOSTNAMEFULL=`/usr/sbin/check-hostname | awk '{print($7)}'`
			;;
		*)
			exit $E_ENVERROR
			;;
	esac
}


#
# Writes a message to stdout using a message bundle.
# $1 .. $9 message parameters
#
echo_message()
{
	CLASSPATH=${RFIDIC_SOLDIR}/lib/com.ibm.rfidic.pharma.epedigree.messages.jar:$CLASSPATH
	java com.ibm.rfidic.pharma.epedigree.messages.GetMessage $1 $2 $3 $4 $5 $6 $7 $8 $9
}


pause()
{
	# Press <ENTER> to continue...
	echo_message FEAT05005I; read
}


#
# Exit with error
#  $1 - exit code
#  $2 .. $9 - error message args (optional)
# 
exitError()
{
	if [ -n "$2" ]; then echo_message $2 $3 $4 $5 $6 $7 $8 $9; fi
	exit $1
}

# determine where script was called from
script_location=`dirname $0 2>/dev/null`
if [ -z "$script_location" ];then
	script_location="."
fi

# determine RFIDIC_SOLDIR
if  [ -f $script_location"/../etc/pedigree.xml" ]
then
        RFIDIC_SOLDIR="`( cd \"${script_location}"/.."\" && pwd )`"
fi
if  [ -n "$RFIDIC_SOLDIR" ] 
then
	echo "RFIDIC_SOLDIR= " $RFIDIC_SOLDIR
else
	RFIDIC_SOLDIR=${RFIDIC_HOME}/features/pedigree
	echo "RFIDIC_SOLDIR= " $RFIDIC_SOLDIR
fi

if [ ! -d "$RFIDIC_SOLDIR" ] 
then
# Just to spit out the 'cannot open directory' message in the language of the OS, 
# since messages cannot be translated without setting the environment.
 	file $RFIDIC_SOLDIR
 	exit
fi

#
# make sure we have the absolute path for RFIDIC_SOLDIR
#
RFIDIC_SOLDIR="`cd \"$RFIDIC_SOLDIR\" 2>/dev/null && pwd || echo \"$RFIDIC_SOLDIR\"`"
echo "RFIDIC_SOLDIR=${RFIDIC_SOLDIR}"

PEDIGREE_HOME=${RFIDIC_SOLDIR}
export PEDIGREE_HOME

# set the RFIDIC environment
if [ -z "$RFIDIC_HOME" ]; then
	RFIDIC_HOME=${RFIDIC_SOLDIR}
	echo "RFIDIC_HOME was not set in the environment. Setting it to ${RFIDIC_HOME}."
fi

# TODO get rid of this
NORFIDIC=false

if [ -z "$RFIDIC_PORT" ]; then
	RFIDIC_PORT=9080
fi

if [ -z "$RFIDIC_HOST" ]; then
	RFIDIC_HOST=$HOSTNAMEFULL
fi

checkPlatform

# RFID IC user
if [ -z "$RFIDIC_USER" ];then 
	RFIDIC_USER=tsadmin
	rfidic_user_password=tsadmin123
fi

PEDIGREE_MQ_HOST=${HOSTNAMEFULL}
PEDIGREE_DB_HOST=${HOSTNAMEFULL}
RFIDIC_DB_HOST=${HOSTNAMEFULL}

export PEDIGREE_MQ_HOST
export PEDIGREE_DB_HOST
export RFIDIC_DB_HOST

determineIP
distributed $PEDIGREE_MQ_HOST
ped_mq_dist=$?

distributed $PEDIGREE_DB_HOST
ped_db_dist=$?

#MQ Settings
if [ -z "$MQ_HOME" ];then
	MQ_HOME=/opt/mqm
fi
if [  -d "$MQ_HOME" ] 
then 
	echo "MQ =$MQ_HOME" 
else 
# Just to spit out the 'cannot open directory' message in the language of the OS, 
# since messages cannot be translated without setting the environment.
if [ ! "$ped_mq_dist" = "0" ];then
	file $MQ_HOME
	exit
fi
fi
if [ -z "$QUEUE_MANAGER" ];then 
	QUEUE_MANAGER=TS.QUEUE.MANAGER
fi
if [ -z "$QNAME_PEDIGREE_EVENT" ];then 
	QNAME_PEDIGREE_EVENT=PedigreeEventIn
fi
if [ -z "$MDM_CHANGE_NOTIF_QUEUE_NAME" ];then 
	MDM_CHANGE_NOTIF_QUEUE_NAME=MDMChangeNotification
fi
if [ -z "$MQ_LSR_PORT" ];then 
	MQ_LSR_PORT=1414
fi
if [ -z "$MQ_USER" ];then
	MQ_USER=${RFIDIC_USER}
fi
if [ -z "$MQ_USER_PASSWORD" ]; then
	MQ_USER_PASSWORD=${rfidic_user_password}
fi

if [ "$ped_mq_dist" = "0" ];then
	MQ_INSTALL_PATH=$MQ_HOME
	MQ_LIB_PATH=$MQ_HOME/java/lib
else
	MQ_INSTALL_PATH=$WAS_HOME/lib/WMQ
	MQ_LIB_PATH=$WAS_HOME/lib/WMQ/java/lib
fi

#### Database settings ######
if [ -z "$DB_TYPE" ];then
	DB_TYPE=INFORMIX
fi

if [ -z "$DBMS_DB_NAME" ];then
	DBMS_DB_NAME=pedigree
	export DBMS_DB_NAME
fi
if [ -z "$DBMS_ADMIN_USER" ];then
	DBMS_ADMIN_USER=tsadmin
	export DBMS_ADMIN_USER
fi
if [ -z "$DBMS_ADMIN_PWD" ];then
	DBMS_ADMIN_PWD=tsadmin123
	export DBMS_ADMIN_PWD
fi
#TODO: the default should not be informix
if [ -z "$DBMS_HOME" ];then
	DBMS_HOME=/opt/IBM/informix
fi
if [ -z "$DBMS_PORT" ];then
	DBMS_PORT=1526
fi

PED_DBMS_LIB_HOME=$DBMS_HOME/jdbc/lib
if [ -z "$DBMS_SERVER" ];then
	DBMS_SERVER=tsdb
	export DBMS_SERVER
fi
DBMS_ALIAS=RFIDICInformixAlias

determineIP

case $DB_TYPE in
	ORACLE)
			DBMS_ALIAS=RFIDICOracleAlias
			ORACLE_GROUP=system
			ORACLE_USER=oracle
			ORACLE_HOME=$DBMS_HOME

			export ORACLE_GROUP
			export ORACLE_USER
			export ORACLE_HOME

			ORACLE_JDBC_URL="jdbc:oracle:thin:@${PEDIGREE_DB_HOST}:${DBMS_PORT}:${DBMS_DB_NAME}"
			;;
	DB2)
			DBMS_ALIAS=RFIDICDb2Alias
			DB2_SERVER=$IP
			DB2_GROUP=db2grp1
			DB2_INSTANCE=db2inst1
			
			export DB2_INSTANCE
			export DB2_GROUP
			export DB2_SERVER
			;;
	*)
			exit $E_ENVERROR
			;;
esac

export DBMS_ALIAS
export PED_DBMS_LIB_HOME
export DBMS_SERVER

if [ ! -d "$DBMS_HOME" ];then
# Just to spit out the 'cannot open directory' message in the language of the OS, 
# since messages cannot be translated without setting the environment.
	if [ "$ped_db_dist" = "0" ];then
 		file $DBMS_HOME
		exit
	fi
fi

#WAS Settings
if [ -z "$WAS_HOME" ];then
	WAS_HOME=/opt/IBM/WebSphere/AppServer
if [ -d "$WAS_HOME" ] 
then
	echo "WAS =" $WAS_HOME
elif [ -d "/opt/IBM/WebSphere/AppServer" ]
then
	WAS_HOME="/opt/IBM/WebSphere/AppServer"
	echo "WAS=  "$WAS_HOME
else 
# Just to spit out the 'cannot open directory' message in the language of the OS, 
# since messages cannot be translated without setting the environment.
 	file $WAS_HOME
	exit
fi
fi

### Document pedigree settings ####
if [ -z "$CAPTURE_TYPE" ];then 
	CAPTURE_TYPE=HTTP
fi
if [ -z "$DOCPEDIGREE_QUEUE" ];then 
	DOCPEDIGREE_QUEUE=DOCUMENTQUEUE
fi
#Application info
DOC_PEDIGREE_CAPTURE_APP_LOCATION=$WAS_HOME/installableApps/DocumentPedigree.ear
DOC_PEDIGREE_CAPTURE_APP_NAME=DocumentPedigreeEAR
DOC_CAPTURE_BUS_NAME=DocPedigreeCaptureBus
DOC_SERVICE_BUS_NAME=DocPedigreeServiceBus

#Global variables to be used for WAS configuration and installation
#These must be replaced with the values derived from the user input / WAS installation

if [ -z "$PROFILENAME" ];then
	PROFILENAME=AppSrv01
fi
if [ -z "$SERVERNAME" ];then
	SERVERNAME=server1
fi
if [ -z "$NODENAME" ];then
	NODENAME="$HOSTNAME"Node01
fi
if [ -z "$CELLNAME" ];then
	CELLNAME="$HOSTNAME"Node01Cell
fi

# Java Settings
if [ -z "$JAVA_HOME" ];then
if [ -d $WAS_HOME ]; then
	JAVA_HOME=$WAS_HOME/java
fi
fi
export JAVA_HOME

#
# check if the path was already modified
#
pathdone=no

oldifs="${IFS}"
IFS=:
for i in $CLASSPATH
do
	if [ "$i" = "$RFIDIC_SOLDIR/lib/com.ibm.rfidic.pharma.epedigree.messages.jar" ];then
	    pathdone=yes
	fi
done
IFS="${oldifs}"

#
# add solution libraries to the CLASSPATH
#
if [ "$pathdone" = "no" ]; then
	for i in $RFIDIC_SOLDIR/lib/*.jar
	do
		CLASSPATH=$i:$CLASSPATH
	done
    
	CLASSPATH=$CLASSPATH:$JAVA_HOME/lib/tools.jar

### TODO: Check if the following are added to the classpath already
	CLASSPATH=$CLASSPATH:$MQ_LIB_PATH/com.ibm.mqjms.jar:$MQ_LIB_PATH/com.ibm.mq.jar:$WAS_HOME/lib/j2ee.jar
	if [ "$DB_TYPE" = "ORACLE" ];then
		CLASSPATH=$CLASSPATH:$PED_DBMS_LIB_HOME/ojdbc6.jar
	elif [ "$DB_TYPE" = "DB2" ];then
		CLASSPATH=$CLASSPATH:$PED_DBMS_LIB_HOME/db2jcc.jar:$PED_DBMS_LIB_HOME/db2jcc_javax.jar:$PED_DBMS_LIB_HOME/db2jcc_license_cu.jar:$PED_DBMS_LIB_HOME/db2jcc_license_cisuz.jar
	fi
	export CLASSPATH

	PATH=$JAVA_HOME/bin:$WAS_HOME/profiles/default/bin:$DBMS_HOME/bin:$WAS_HOME/bin:$PATH
	export PATH
fi
ENABLE_DOCUMENT_PEDIGREE=Y

WS_USER_1=$WS_USER_1
WS_PWD_1=$WS_PWD_1
WS_SSL_1=$WS_SSL_1

WS_USER_2=$WS_USER_2
WS_PWD_2=$WS_PWD_2
WS_SSL_2=$WS_SSL_2 

WS_USER_3=$WS_USER_3
WS_PWD_3=$WS_PWD_3
WS_SSL_3=$WS_SSL_3

WS_USER_4=$WS_USER_4
WS_PWD_4=$WS_PWD_4
WS_SSL_4=$WS_SSL_4

WS_USER_5=$WS_USER_5
WS_PWD_5=$WS_PWD_5
WS_SSL_5=$WS_SSL_5

# runs a command and terminates if the exit code is non-zero
run_command()
{
	"$@"
	retcode=$?
	if [ "$retcode" -ne 0 ]
	then
		echo "run_command : following command failed with non-zero return code ($retcode)... exiting"
		echo  "$@"
		exit $retcode
	fi
}

getDBVersion(){
	unset DBversion
	cp=${RFIDIC_SOLDIR}/lib/com.ibm.rfidic.pedigree.install.syscheck.jar:${RFIDIC_SOLDIR}/lib/commons-dbutils-1.1.jar
	appendClassPathWithWASJars
	if [ "$DB_TYPE" = "ORACLE" ];then
		cp=$cp:${PED_DBMS_LIB_HOME}/ojdbc6.jar
		driverClassName="oracle.jdbc.OracleDriver"
		JDBC="$ORACLE_JDBC_URL"
		echo "${WAS_HOME}/java/bin/java -classpath $cp com.ibm.rfidic.pedigree.install.syscheck.SQLFileExecutor ${JDBC} ${driverClassName} ${DBMS_ADMIN_USER} ${DBMS_ADMIN_PWD} ${PEDIGREE_HOME}/bin/Oracle/VersionCheck.sql"
		${WAS_HOME}/java/bin/java -classpath $cp com.ibm.rfidic.pedigree.install.syscheck.SQLFileExecutor ${JDBC} ${driverClassName} ${DBMS_ADMIN_USER} ${DBMS_ADMIN_PWD} ${PEDIGREE_HOME}/bin/Oracle/VersionCheck.sql  1>&2 > /tmp/VersionOutput.txt
		DBversion=`cat /tmp/VersionOutput.txt | grep "Release" | awk '{print($7)}'`
	elif [ "$DB_TYPE" = "DB2" ];then
              cp=$cp:${PED_DBMS_LIB_HOME}/db2jcc.jar:${PED_DBMS_LIB_HOME}/db2jcc_license_cu.jar
		driverClassName="com.ibm.db2.jcc.DB2Driver"
		JDBC="jdbc:db2://${PEDIGREE_DB_HOST}:${DBMS_PORT}/${DBMS_DB_NAME}"
		${WAS_HOME}/java/bin/java -classpath $cp com.ibm.rfidic.pedigree.install.syscheck.SQLFileExecutor ${JDBC} ${driverClassName} ${DBMS_ADMIN_USER} ${DBMS_ADMIN_PWD} ${PEDIGREE_HOME}/bin/DB2/VersionCheck.sql  1>&2 > /tmp/VersionOutput.txt
		DBversion=`cat /tmp/VersionOutput.txt | grep "DB2" | awk '{print($2)}'`
	fi
       rm -f /tmp/VersionOutput.txt
	export DBversion
}

appendClassPathWithWASJars()
{
if [ -n  "$wascpathdone" ]; then
       echo_verbose "CLASSPATH=" $CLASSPATH
else
			#Classpath for WAS 7.0
	 	CLASSPATH=$CLASSPATH:$WAS_HOME/runtimes/com.ibm.ws.webservices.thinclient_7.0.0.jar
		CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/com.ibm.ws.security.crypto.jar
		CLASSPATH=$CLASSPATH:$WAS_HOME/lib/bootstrap.jar:$WAS_HOME/plugins/com.ibm.ws.runtime.jar
		CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/com.ibm.ws.prereq.wsdl4j.jar
	 	CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/org.eclipse.equinox.common_.jar
	 	CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/com.ibm.ws.bootstrap.jar
	 	CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/org.eclipse.equinox.registry.jar
	 	CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/org.eclipse.core.runtime_.jar
	 	CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/com.ibm.ffdc.jar
	 	CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/org.eclipse.osgi_.jar
	 	CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/com.ibm.ws.admin.core.jar
	 	CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/javax.j2ee.management.jar
	 	CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/com.ibm.ws.wlm.jar
	 	
	 	#Classpath for WAS 6.1
		CLASSPATH=$CLASSPATH:$WAS_HOME/lib/j2ee.jar:$WAS_HOME/lib/webservices.jar:$WAS_HOME/installedChannels/channel.http.jar:$WAS_HOME/installedChannels/channel.tcp.jar:$WAS_HOME/installedChannels/channel.ssl.jar:$WAS_HOME/lib/naming.jar
	CLASSPATH=$CLASSPATH:$WAS_HOME/runtimes/com.ibm.ws.webservices.thinclient_6.1.0.jar
	CLASSPATH=$CLASSPATH:$WAS_HOME/plugins/com.ibm.ws.security.crypto_6.1.0.jar
	export CLASSPATH
	wascpathdone=yes
	export wascpathdone
fi
}

sslWASSettings()
{
   echo "-Djava.protocol.handler.pkgs=com.ibm.net.ssl.internal.www2.protocol -Djavax.net.ssl.trustStore="$WAS_HOME/profiles/$PROFILENAME/etc/DummyClientTrustFile.jks" -Djavax.net.ssl.trustStorePassword=WebAS -Djavax.net.ssl.keyStore="$WAS_HOME/profiles/$PROFILENAME/etc/DummyClientTrustFile.jks" -Djavax.net.ssl.keyStorePassword=WebAS -Djavax.net.ssl.keyStoreType=JKS -Djavax.net.ssl.trustStoreType=JKS -Djavax.net.ssl.protocol=SSL"
}

asciiUpdate(){
	# Takes an array of search and replace strings for a file, constructs the sed script and performs the update on the file
        index=0
        searchStr=$2
        replaceStr=$3
        count=${#searchStr[*]}
        command="{\n"
        while [ "$index" -lt "$count" ]
        do
                command=$command"s%"${searchStr[$index]}"%"${replaceStr[$index]}"%g\n"
                index=`expr $index + 1`
        done
        command=$command"}"
        $ECHO "$command" > $1.sed
       run_command sed -f $1.sed $1 > $1.tmp
	run_command mv -f $1.tmp $1
	run_command rm -f $1.sed
	unset searchStr
	unset replaceStr
}

echo_msg(){
   $ECHO $1 | tee -a $LOG
}
