#!/bin/ksh
#############################################################################
## Licensed Materials - Property of IBM
##
## Governed under the terms of the International
## License Agreement for Non-Warranted Sample Code.
##
## (C) COPYRIGHT International Business Machines Corp. 2008, 2012
## All Rights Reserved.
##
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##
##   Title: pedigree-mq-cfg.sh	
##   Description: Configures MQ Manager and Queues
##   Usage: pedigree-mq-cfg.sh -clean | -eped | -all | -docped
##          -clean   delete queue manager and queues
##          -all     create queue manager and queues for both event pedigree and doc pedigree
##	     	-docped  create queue for document pedigree only
##	     	-help  print the usage
##        	none     create queue for event epedigree only
##
#############################################################################

# include the Pedigree environment settings
SCRIPT_DIR=`dirname $0`
. ${SCRIPT_DIR}/pedigree-env.sh

distributed $PEDIGREE_MQ_HOST
mq_dist=$?
if [ ! "$mq_dist" = "0" ];then
	#MQ is not local
	echo "Please configure WebSphere MQ manually. See the install guide for details."
	exit 0
fi	

PLATFORM=`/bin/uname`

usage()
{
  echo "Usage: pedigree-mq-cfg.sh -clean | -all | -docped"
  echo "       -clean   delete queue manager and queues"
  echo "       -all     create queue manager and queues for both event pedigree and doc pedigree"
  echo "	   -docped  create queue for document pedigree only"
  echo "	   -help  print the usage"
  echo "  	   none     create queue for event pedigree only"
  
}

startChannel()
{
  ${MQ_HOME}/bin/runmqsc ${QUEUE_MANAGER} 1>&2 > /tmp/channelStatus.txt << EOF6
	DISPLAY CHSTATUS(SYSTEM.ADMIN.SVRCONN)
EOF6
  state=`cat /tmp/channelStatus.txt | grep "AMQ8417"`
  if [ -z "$state" ];then
	   run_command ${MQ_HOME}/bin/runmqsc ${QUEUE_MANAGER} << EOF7
        START CHANNEL(SYSTEM.ADMIN.SVRCONN)
EOF7
fi
rm -f /tmp/channelStatus.txt
}

setMQPort()
{
	while `grep $MQ_LSR_PORT /etc/services>/dev/null`
	do
		echo "Another application is running on the $MQ_LSR_PORT port."
		let MQ_LSR_PORT=MQ_LSR_PORT+1
		echo "Trying to register WebSphere MQ at the $MQ_LSR_PORT port."
	done
	echo "WebSphere MQ is registered at the $MQ_LSR_PORT port."
	echo  "mqm		$MQ_LSR_PORT/tcp			# MQ Series Port" >> /etc/services
export MQ_LSR_PORT
}

# check environment
if [ -z "$QUEUE_MANAGER" -o -z "$MQ_LSR_PORT" -o -z "$MQ_USER" ]; then
	# Undefined or incomplete environment
	echo_message FEAT05208I "QUEUE_MANAGER=\"$QUEUE_MANAGER\" MQ_LSR_PORT=\"$MQ_LSR_PORT\" MQ_USER=\"$MQ_USER\""

	# Please check the following files: ...
	echo_message FEAT05212I "  $RFIDIC_SOLDIR/bin/pedigree-env.sh   $RFIDIC_HOME/bin/rfidic-env.sh"
	exitError $E_OPTERROR
fi

#
# Parse the command line
#
unset mqConfigClean
unset mqConfigQMgr
unset mqEped
unset mqDocped
mqEped=1
for item in $*
  do
     if [ `expr match "$item" '-clean'` != 0 ];then
	   mqConfigClean=1
	   mqEped=0
     elif [ `expr match "$item" '-all'` != 0 ];then
	   mqConfigQMgr=1
          mqEped=1
          mqDocped=1
     elif [ `expr match "$item" '-docped'` != 0 ];then
	   	  mqConfigQMgr=1
          mqDocped=1
          mqEped=0
     elif [ `expr match "$item" '-help'` != 0 ];then
            usage
            exit
     else
     		echo "Execute the script with only one of the options as given below"
            usage
            exit
     fi
done


if [ "$mqConfigClean" ]; then
  #echo "Unconfiguring MQ..."
  pedigree-get-message.sh TSIN01243I

  # delete the queues
  ${MQ_HOME}/bin/runmqsc ${QUEUE_MANAGER} << EOF5
  DELETE QLOCAL ('${QNAME_PEDIGREE_EVENT}')
  DELETE QLOCAL ('${DOCPEDIGREE_QUEUE}')
EOF5

exit 0
fi

if [ "$mqConfigQMgr" ]; then
	if [ "$PLATFORM" = "SunOS" ];then
		mqmngr=`${MQ_HOME}/bin/dspmq -m ${QUEUE_MANAGER} | awk '{print($2)}' | awk -F"(" '{print($2)}'`
	else
		mqmngr=`${MQ_HOME}/bin/dspmq -m ${QUEUE_MANAGER} | awk '{print($2)}' | awk -F "(" '{print($2)}'`
	fi
	if [ -z "$mqmngr" ];then
  		setMQPort
  		run_command ${MQ_HOME}/bin/crtmqm -lp 30 -ls 20 -q ${QUEUE_MANAGER}
  		run_command ${MQ_HOME}/bin/strmqm ${QUEUE_MANAGER}
  		run_command ${MQ_HOME}/bin/runmqlsr -t tcp -m ${QUEUE_MANAGER} -p ${MQ_LSR_PORT} &
  		run_command ${MQ_HOME}/bin/runmqsc ${QUEUE_MANAGER} << EOF1
		DEFINE CHANNEL(SYSTEM.ADMIN.SVRCONN) chltype(svrconn) TRPTYPE(TCP) mcauser('${MQ_USER}')
		
EOF1
  	# Updating pedigree-env.sh
  	run_command sed "s,MQ_LSR_PORT=[0-9]*,MQ_LSR_PORT=$MQ_LSR_PORT," $RFIDIC_SOLDIR/bin/pedigree-env.sh > $RFIDIC_SOLDIR/bin/pedigree-env.sh.temp
  	run_command mv -f  $RFIDIC_SOLDIR/bin/pedigree-env.sh.temp $RFIDIC_SOLDIR/bin/pedigree-env.sh
  	#chown $RFIDIC_USER:$RFIDIC_GROUP $RFIDIC_SOLDIR/bin/pedigree-env.sh
  	run_command chmod 750 $RFIDIC_SOLDIR/bin/pedigree-env.sh
	elif [ "$mqmngr" = "Running)" ];then
		echo "Using the Queue manager ${QUEUE_MANAGER}"
	elif [ ! "$mqmngr" = "Running)" ];then
		echo "Restarting the queue manager ${QUEUE_MANAGER}"
		${MQ_HOME}/bin/endmqm -w ${QUEUE_MANAGER}
		${MQ_HOME}/bin/strmqm ${QUEUE_MANAGER}
		str=$?
		if [ "$str" -ne 0 ];then
			echo "Queue manager could not be started. Please check the queue manager and try again."
			exit 1
		fi
	fi
	run_command ${MQ_HOME}/bin/runmqsc ${QUEUE_MANAGER} << EOF8
        ALTER qmgr MAXMSGL(100000000)
	 ALTER CHANNEL(SYSTEM.DEF.SVRCONN) CHLTYPE (SVRCONN) maxmsgl (100000000)
EOF8

fi

if [ "$mqEped" ]; then
       run_command ${MQ_HOME}/bin/runmqsc ${QUEUE_MANAGER} << EOF2
       DEFINE QLOCAL ('${QNAME_PEDIGREE_EVENT}') DEFPSIST(YES) LIKE(SYSTEM.DEFAULT.LOCAL.QUEUE) DESCR('Pedigree event queue') SHARE REPLACE
	
EOF2
startChannel
fi

if [ "$mqDocped" ]; then
    run_command ${MQ_HOME}/bin/runmqsc ${QUEUE_MANAGER} << EOF4
     DEFINE QLOCAL ('${DOCPEDIGREE_QUEUE}') DEFPSIST(YES) LIKE(SYSTEM.DEFAULT.LOCAL.QUEUE) DESCR('Input Queue of the capture interface for document pedigree') SHARE REPLACE        
     ALTER QLOCAL ('${DOCPEDIGREE_QUEUE}') MAXMSGL(100000000)
EOF4
startChannel
fi
exit 0