#!/bin/ksh
#
# Licensed Materials - Property of IBM
#
# Governed under the terms of the International
# License Agreement for Non-Warranted Sample Code.
#
# 5724-O98 (C) COPYRIGHT International Business Machines Corp. 2006, 2012
# All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
#
# pedigreeDeploy.sh - deploys Pedigree Metadata and imports the master data for standard, country and vocabulary
#   Prompts the user when loading event data.
#
# Usage: pedigreeDeploy.sh [-dba_user=<value of dba user for TS Database>] [-dba_password=<value>] [-was_admin_user=<value>] [-was_admin_password=<value>] [-was_runas_user=<value>]
#############################################################################

# ---------------------------------------------------------------------
# Main
#
# setup solution environment
#
SCRIPT_DIR=`dirname ${0}`
if [ -f ${SCRIPT_DIR}/pedigree-env.sh ]; then
	. ${SCRIPT_DIR}/pedigree-env.sh
else
	# "$0 : File not found ${SCRIPT_DIR}/pedigree-env.sh"
	exit -1
fi

echo_msg(){
   echo $1 | tee -a $LOG
}

usage(){
	pedigree-get-message.sh TSIN02158I
	#echo_msg "USAGE: ./pedigreeDeploy.sh [-dba_user=<value of dba user for TS Database>] [-dba_password=<value>] [-was_admin_user=<value>] [-was_admin_password=<value>] [-was_runas_user=<value>] [-sec_pol_file=<absolute file path if you want to overwrite default one in /etc>] [-master_data_file=<absolute file path if you want to import additional master data file>]"
	exit 1
}

webserviceCall()
{
	PATHTOFILE=$1
	SOAP=$2
	if [ -n "$was_admin_user" -a -n "$was_admin_password" ]
	then
		$PEDIGREE_HOME/bin/callWebService.sh -was_admin_user=$was_admin_user -was_admin_password=$was_admin_password -path=$PATHTOFILE -soap=$SOAP
	else
		$PEDIGREE_HOME/bin/callWebService.sh -path=$PATHTOFILE -soap=$SOAP
	fi
}

for item in $*
do
	if [ `expr match "$item" '-dba_user'` != 0 ];then
              dba_user=`echo ${item#-dba_user=}`
	elif [ `expr match "$item" '-dba_password'` != 0 ];then
              dba_password=`echo ${item#-dba_password=}`
	elif [ `expr match "$item" '-was_admin_user'` != 0 ];then
              was_admin_user=`echo ${item#-was_admin_user=}`    
	elif [ `expr match "$item" '-was_admin_password'` != 0 ];then
              was_admin_password=`echo ${item#-was_admin_password=}`    
   	elif [ `expr match "$item" '-was_runas_user'` != 0 ];then
      		was_runas_user=`echo ${item#-was_runas_user=}`
   	elif [ `expr match "$item" '-sec_pol_file'` != 0 ];then
      		sec_pol_file=`echo ${item#-sec_pol_file=}`
   	elif [ `expr match "$item" '-master_data_file'` != 0 ];then
      		master_data_file=`echo ${item#-master_data_file=}`
	else
            usage
	fi
done


if [ -n "$was_admin_user" -a -z "$was_admin_password" ];then
       rfidic-get-message.sh -noid RFID05057I "$was_admin_user: "
	stty -echo
	read was_admin_password
	stty echo
fi
if [ -n "$was_admin_user" -a -n "$was_admin_password" ];then
        tsar_was_credentials="-was_admin_user $was_admin_user -was_admin_password $was_admin_password"
	credentials="-was_admin_user=$was_admin_user -was_admin_password=$was_admin_password"
	wsadmin_creds="-conntype SOAP -user $was_admin_user -password $was_admin_password"
fi
if [ -n "$was_runas_user" ];then
	was_runas="-was_runas_user=$was_runas_user"
fi


		$TS_HOME/bin/importReplaceTSAR.sh -file $TS_HOME/samples/epedigree/tsar/pedigree_sample.tsar $tsar_was_credentials -force

		# clean up MQ
		$TS_HOME/bin/stopTS.sh -components=was $credentials
        echo "display queue('$QNAME_PEDIGREE_EVENT') curdepth" | runmqsc
        if [ $? -eq 0 ]
        then
            echo "clear qlocal('$QNAME_PEDIGREE_EVENT')" | runmqsc
		fi

		pedigree-get-message.sh TSIN02117I
		#echo_msg "Starting WAS"
		$TS_HOME/bin/startTS.sh $credentials

		echo_msg " "
		pedigree-get-message.sh TSIN02160I
		#echo_msg "----------- Importing Pedigree Vocabularies ---------------"

		#### load pedigree master data into the TS repository ###
		pedigree-get-message.sh TSIN02119I
		#echo_msg "Importing Master Data - Standard Vocabulary"
		run_command ${TS_HOME}/bin/importMasterdata.sh $TS_HOME/samples/mdm/CoreBusinessVocabulary.xml
		pedigree-get-message.sh TSIN02128I
		#echo_msg "Importing Master Data - Country Vocabulary"
		run_command ${TS_HOME}/bin/importMasterdata.sh $PEDIGREE_HOME/samples/epedigree/mdm/countryVocabulary.xml
		pedigree-get-message.sh TSIN02129I
		#echo_msg "Importing Master Data - Region Vocabulary"
		run_command ${TS_HOME}/bin/importMasterdata.sh $PEDIGREE_HOME/samples/epedigree/mdm/regionVocabularies.xml
		# If the parameter master_data_file is passed then that also is imported by the script
		if [ -n "$master_data_file" ]; then
			echo_msg "Importing Master Data - Custom"
			run_command ${TS_HOME}/bin/importMasterdata.sh $master_data_file
		fi
		
		pedigree-get-message.sh TSIN02162I 
		#echo_msg "Pedigree Deploy Successful"
