#!/bin/ksh 
#############################################################################
## Licensed Materials - Property of IBM
##
## Governed under the terms of the International
## License Agreement for Non-Warranted Sample Code.
##
## (C) COPYRIGHT International Business Machines Corp. 2008, 2012
## All Rights Reserved.
##
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##
##   Title: setPedWebServicesBindingInfoMain.sh	
##   Description: Configures Pedigree WebServices with Security Bindings
##   Usage: setPedWebServicesBindingInfoMain.sh  
##  -was_admin_user optional argument if WAS is security enabled
##  -was_admin_password optional argument if was_admin_user needs to be passed
##
#############################################################################

#
# setup solution environment
#
SCRIPT_DIR=`dirname ${0}`
if [ -f ${SCRIPT_DIR}/pedigree-env.sh ]; then
	. ${SCRIPT_DIR}/pedigree-env.sh
else
	#"$0 : File not found ${SCRIPT_DIR}/pedigree-env.sh"
	exit 1
fi

for item in $*
do
		if [ `expr match "$item" '-was_admin_user'` != 0 ]; then
                  was_admin_user=`echo ${item#-was_admin_user=}`
		elif [ `expr match "$item" '-was_admin_password='` != 0 ]; then
        	    was_admin_password=`echo ${item#-was_admin_password=}`
		else
			echo "Unknown Parameter"
            exit "1"
        fi
done


######### Setting the client side WS Binding Info for securing internal webservices####################

if [ -n "$was_admin_user" -a -n "$was_admin_password" ];then
     credentials="-was_admin_user=$was_admin_user -was_admin_password=$was_admin_password"
	wsadmin_creds="-conntype SOAP -user $was_admin_user -password $was_admin_password"
fi

if [ -n "$was_admin_user" ];then
	ENDPOINT_URL_PREFIX="https://${RFIDIC_HOST}:${RFIDIC_PORT}"
	mappedUsersFile=/tmp/EARMappedUsers

	# Add $WS_USER_1 to DocRepository role of DocumentPedigreeEAR
	APP_NAME="DocumentPedigreeEAR"
	ROLE_NAME="DocRepository"

	run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $wsadmin_creds -c '$AdminApp view DocumentPedigreeEAR {-MapRolesToUsers}' > $mappedUsersFile
	java com.ibm.rfidic.utils.install.ReadMappedUserGroups $mappedUsersFile "$ROLE_NAME" "$WS_USER_1"
	xvar=`cat $mappedUsersFile`
	run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $wsadmin_creds -f $PEDIGREE_HOME/bin/jacl/addUsrOrGrpToSecurityRole.jacl $SERVERNAME $NODENAME $CELLNAME "$xvar" "$APP_NAME" "$ROLE_NAME" "user"
	rm -rf $mappedUsersFile

	# Add WS_USER_2,WS_USER_4,WS_USER_5 to EPCISQuery role for com.ibm.ts.webEAR
	APP_NAME="com.ibm.ts.webEAR"
	ROLE_NAME="EPCISQuery"
	run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $wsadmin_creds -c "\$AdminApp view \"$APP_NAME\" {-MapRolesToUsers}" > $mappedUsersFile
	java com.ibm.rfidic.utils.install.ReadMappedUserGroups $mappedUsersFile "$ROLE_NAME" "$WS_USER_2|$WS_USER_4|$WS_USER_5"
	xvar=`cat $mappedUsersFile`
	run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $wsadmin_creds -f $PEDIGREE_HOME/bin/jacl/addUsrOrGrpToSecurityRole.jacl $SERVERNAME $NODENAME $CELLNAME "$xvar" "$APP_NAME" "$ROLE_NAME" "user"
	rm -rf $mappedUsersFile

	# Add WS_USER_3 to PedigreeService role of PedigreeEAR
	APP_NAME="com.ibm.epcis.pharma.pedigreeEAR"
	ROLE_NAME="PedigreeService"
	run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $wsadmin_creds -c '$AdminApp view com.ibm.epcis.pharma.pedigreeEAR {-MapRolesToUsers}' > $mappedUsersFile
	java com.ibm.rfidic.utils.install.ReadMappedUserGroups $mappedUsersFile "$ROLE_NAME" "$WS_USER_3"
	xvar=`cat $mappedUsersFile`
	run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $wsadmin_creds -f $PEDIGREE_HOME/bin/jacl/addUsrOrGrpToSecurityRole.jacl $SERVERNAME $NODENAME $CELLNAME "$xvar" "$APP_NAME" "$ROLE_NAME" "user"
	rm -rf $mappedUsersFile
	
else
	ENDPOINT_URL_PREFIX="http://${RFIDIC_HOST}:${RFIDIC_PORT}"
fi
# Properties for Pedigree app - ws.war
APP_NAME=com.ibm.epcis.pharma.pedigreeEAR
APP_MODULE=com.ibm.epcis.pharma.pedigree.ws.war
APP_SERVICE="service/DocRepositoryService"
APP_PORT="\{http://pedigree.rfidic.ibm.com/DocRepository\}DocRepository"
APP_EPU=$ENDPOINT_URL_PREFIX"/com.ibm.rfidic.pedigree.doc.repository.ws/services/DocRepository"
WSBindingParams="-user=$WS_USER_1 -password=$WS_PWD_1 -ssl_config=$WS_SSL_1 $credentials -timeout=none"
run_command ${PEDIGREE_HOME}/bin/setWebServicesBindingInfo.sh ${WSBindingParams} -APP_NAME=$APP_NAME -APP_MODULE=$APP_MODULE -APP_EJB="none" -APP_SERVICE=$APP_SERVICE -APP_PORT=$APP_PORT -APP_EPU=$APP_EPU 

# Properties for pedigree ui.partners.war
APP_NAME=com.ibm.rfidic.pharma.epedigree.uiEAR
APP_MODULE=com.ibm.rfidic.pharma.epedigree.ui.partners.war
APP_SERVICE="service/EPCglobalEPCISService"
APP_PORT="\{urn:epcglobal:epcis:wsdl:1\}EPCglobalEPCISServicePort" 
APP_EPU=$ENDPOINT_URL_PREFIX"/ts/engine/services/EPCglobalEPCISService"
WSBindingParams="-user=$WS_USER_2 -password=$WS_PWD_2 -ssl_config=$WS_SSL_2 $credentials -timeout=none"
run_command ${PEDIGREE_HOME}/bin/setWebServicesBindingInfo.sh ${WSBindingParams} -APP_NAME=$APP_NAME -APP_MODULE=$APP_MODULE -APP_EJB="none" -APP_SERVICE=$APP_SERVICE -APP_PORT=$APP_PORT -APP_EPU=$APP_EPU 

# Properties for pedigree ui.war
APP_NAME=com.ibm.rfidic.pharma.epedigree.uiEAR
APP_MODULE=com.ibm.rfidic.pharma.epedigree.ui.war
APP_SERVICE="service/PedigreeService"
APP_PORT="\{http://www.ibm.com/epcis/pedigree/PedigreeService/1.5\}PedigreeServicePort" 
APP_EPU=$ENDPOINT_URL_PREFIX"/com.ibm.epcis.pedigree.ws/services/PedigreeServicePort"
WSBindingParams="-user=$WS_USER_3 -password=$WS_PWD_3 -ssl_config=$WS_SSL_3 $credentials -timeout=none"
run_command ${PEDIGREE_HOME}/bin/setWebServicesBindingInfo.sh ${WSBindingParams} -APP_NAME=$APP_NAME -APP_MODULE=$APP_MODULE -APP_EJB="none" -APP_SERVICE=$APP_SERVICE -APP_PORT=$APP_PORT -APP_EPU=$APP_EPU 

APP_NAME=com.ibm.epcis.pharma.pedigreeEAR
APP_MODULE=com.ibm.epcis.pharma.pedigree.ws.war
APP_SERVICE="service/EPCglobalEPCISService"
APP_PORT="\{urn:epcglobal:epcis:wsdl:1\}EPCglobalEPCISServicePort"
APP_EPU=$ENDPOINT_URL_PREFIX"/ts/engine/services/EPCglobalEPCISService"
WSBindingParams="-user=$WS_USER_4 -password=$WS_PWD_4 -ssl_config=$WS_SSL_4 $credentials -timeout=3600"
run_command ${PEDIGREE_HOME}/bin/setWebServicesBindingInfo.sh ${WSBindingParams} -APP_NAME=$APP_NAME -APP_MODULE=$APP_MODULE -APP_EJB="none" -APP_SERVICE=$APP_SERVICE -APP_PORT=$APP_PORT -APP_EPU=$APP_EPU

APP_NAME=com.ibm.epcis.pharma.pedigreeEAR
APP_MODULE=com.ibm.rfidic.pedigree.mdb.jar
APP_EJB="PedigreeEventMDBean"
APP_SERVICE="service/EPCglobalEPCISService"
APP_PORT="\{urn:epcglobal:epcis:wsdl:1\}EPCglobalEPCISServicePort"
APP_EPU=$ENDPOINT_URL_PREFIX"/ts/engine/services/EPCglobalEPCISService"
WSBindingParams="-user=$WS_USER_5 -password=$WS_PWD_5 -ssl_config=$WS_SSL_5 $credentials -timeout=none"
run_command ${PEDIGREE_HOME}/bin/setWebServicesBindingInfo.sh ${WSBindingParams} -APP_NAME=$APP_NAME -APP_MODULE=$APP_MODULE -APP_EJB=$APP_EJB -APP_SERVICE=$APP_SERVICE -APP_PORT=$APP_PORT -APP_EPU=$APP_EPU

APP_NAME=com.ibm.epcis.pharma.pedigreeEAR
APP_MODULE=com.ibm.rfidic.pedigree.mdb.jar
APP_EJB="PedigreeServiceJMS"
APP_SERVICE="service/EPCglobalEPCISService"
APP_PORT="\{urn:epcglobal:epcis:wsdl:1\}EPCglobalEPCISServicePort"
APP_EPU=$ENDPOINT_URL_PREFIX"/ts/engine/services/EPCglobalEPCISService"
WSBindingParams="-user=$WS_USER_5 -password=$WS_PWD_5 -ssl_config=$WS_SSL_5 $credentials -timeout=none"
run_command ${PEDIGREE_HOME}/bin/setWebServicesBindingInfo.sh ${WSBindingParams} -APP_NAME=$APP_NAME -APP_MODULE=$APP_MODULE -APP_EJB=$APP_EJB -APP_SERVICE=$APP_SERVICE -APP_PORT=$APP_PORT -APP_EPU=$APP_EPU

APP_NAME=com.ibm.rfidic.pharma.epedigree.uiEAR
APP_MODULE=com.ibm.rfidic.pharma.epedigree.ui.war
APP_SERVICE="service/DocRepositoryService"
APP_PORT="\{http://pedigree.rfidic.ibm.com/DocRepository\}DocRepository"
APP_EPU=$ENDPOINT_URL_PREFIX"/com.ibm.rfidic.pedigree.doc.repository.ws/services/DocRepository"
WSBindingParams="-user=$WS_USER_1 -password=$WS_PWD_1 -ssl_config=$WS_SSL_1 $credentials"
run_command ${PEDIGREE_HOME}/bin/setWebServicesBindingInfo.sh ${WSBindingParams} -APP_NAME=$APP_NAME -APP_MODULE=$APP_MODULE -APP_EJB="none" -APP_SERVICE=$APP_SERVICE -APP_PORT=$APP_PORT -APP_EPU=$APP_EPU

APP_NAME=com.ibm.epcis.pharma.pedigreeEAR
APP_MODULE=com.ibm.rfidic.pedigree.mdb.jar
APP_EJB="PedigreeServiceJMS"
APP_SERVICE="service/DocRepositoryService"
APP_PORT="\{http://pedigree.rfidic.ibm.com/DocRepository\}DocRepository"
APP_EPU=$ENDPOINT_URL_PREFIX"/com.ibm.rfidic.pedigree.doc.repository.ws/services/DocRepository"
WSBindingParams="-user=$WS_USER_1 -password=$WS_PWD_1 -ssl_config=$WS_SSL_1 $credentials -timeout=none"
run_command ${PEDIGREE_HOME}/bin/setWebServicesBindingInfo.sh ${WSBindingParams} -APP_NAME=$APP_NAME -APP_MODULE=$APP_MODULE -APP_EJB=$APP_EJB -APP_SERVICE=$APP_SERVICE -APP_PORT=$APP_PORT -APP_EPU=$APP_EPU


######### End of Settting the client side WS Binding Info ####################

exit 0
