#!/bin/ksh
#
# Licensed Materials - Property of IBM
#
# Governed under the terms of the International
# License Agreement for Non-Warranted Sample Code.
#
# 5724-O98 (C) COPYRIGHT International Business Machines Corp. 2006, 2012
# All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
#
# setupSample.sh - setup sample configuration and load sample master data, 
#   solution, and event data for the ePedigree feature.
#   Prompts the user when loading event data.
#
# Usage: setupSample.sh
#############################################################################

# ---------------------------------------------------------------------
# Main
#
# setup solution environment
#
echo_msg(){
   echo $1 | tee -a $LOG
}

continueOrExit(){
	pedigree-get-message.sh -noid TSIN01260I
	#echo_msg "\nAre you sure you want to continue?"
	pedigree-get-message.sh TSIN01220I
	#echo_msg "Press 1 to continue"
	pedigree-get-message.sh TSIN01221I
	#echo_msg "Press 2 to exit the operation"
	read ans
	if [ "$ans" = "1" ];then
		return 1
	elif [ "$ans" = "2" ];then
		exit 1		
	else
		pedigree-get-message.sh TSIN01011E
		#echo_msg "Invalid input. Try again"
		exit 1
	fi
}
promptDBAUser(){
	dbToPrompt=$1
	if [ -z "$dba_user" ];then
		pedigree-get-message.sh TSIN01017I
		#echo_msg "Enter the dba user for the database $dbToPrompt"
		read dba_user
	fi
	if [ -n "$dba_user" -a -z "$dba_password" ];then
		pedigree-get-message.sh TSIN01018I $dba_user
		#echo_msg "Enter the password for the user $dba_user:"
		stty -echo
		read dba_password
		stty echo
	fi
	if [ "$dbToPrompt" = "TraceabilityServer" ];then
		ts_dba_user=$dba_user
		ts_dba_password=$dba_password
	else
		ped_dba_user=$dba_user
		ped_dba_password=$dba_password
	fi
}
webserviceCall()
{
	PATHTOFILE=$1
	SOAP=$2
	if [ -n "$was_admin_user" -a -n "$was_admin_password" ]
	then
		$PEDIGREE_HOME/bin/callWebService.sh -was_admin_user=$was_admin_user -was_admin_password=$was_admin_password -path=$PATHTOFILE -soap=$SOAP
	else
		$PEDIGREE_HOME/bin/callWebService.sh -path=$PATHTOFILE -soap=$SOAP
	fi
}

usage(){
pedigree-get-message.sh TSIN02107I
#echo_msg " Usage: "
#echo_msg " 	   ./setupSample.sh [-was_admin_user=<value>] [-was_admin_password=<value>] [-was_admin_group=<value>] [-was_runas_user=<value>] [-dba_user=<value>] [-dba_password=value]"
echo_msg " 	                    [-scenario=<value>] The values can be 'EVENT' or 'DOCUMENT'. By default it is 'EVENT'"
echo_msg " 	                    [-help] Prints the usage"
exit 1
}


unset DBMS_DB_NAME;unset DBMS_HOME;unset DBMS_ADMIN_USER;unset DBMS_ADMIN_PWD;unset DB_TYPE;unset DBMS_PORT;unset DBMS_SERVER
unset WAS_HOME;unset PROFILENAME;unset CELLNAME;unset NODENAME;unset SERVERNAME
unset MQ_HOME;unset QUEUE_MANAGER;unset MQ_LSR_PORT;unset MQ_USER
unset RFIDIC_HOME;unset RFIDIC_USER

SCRIPT_DIR=`dirname ${0}`
#echo "Going to execute "
if [ -f ${SCRIPT_DIR}/pedigree-env.sh ]; then
	. ${SCRIPT_DIR}/pedigree-env.sh
else
	# "$0 : File not found ${SCRIPT_DIR}/pedigree-env.sh"
	exit -1
fi

LOG=${RFIDIC_SOLDIR}/bin/setupSample.log
rm -rf $LOG

scenario=EVENT
for item in $*
do
	if [ `expr match "$item" '-was_admin_user'` != 0 ];then
              was_admin_user=`echo ${item#-was_admin_user=}`    
	elif [ `expr match "$item" '-was_admin_password'` != 0 ];then
              was_admin_password=`echo ${item#-was_admin_password=}`    
   	elif [ `expr match "$item" '-was_runas_user'` != 0 ];then
      		was_runas_user=`echo ${item#-was_runas_user=}`
   	elif [ `expr match "$item" '-was_admin_group'` != 0 ];then
      		was_admin_group=`echo ${item#-was_admin_group=}`
   	elif [ `expr match "$item" '-dba_user'` != 0 ];then
      		dba_user=`echo ${item#-dba_user=}`
   	elif [ `expr match "$item" '-dba_password'` != 0 ];then
      		dba_password=`echo ${item#-dba_password=}`
   	elif [ `expr match "$item" '-scenario'` != 0 ];then
      		scenario=`echo ${item#-scenario=}`
      		if [ ! "$scenario" = "EVENT" -a ! "$scenario" = "DOCUMENT" ];then
      			usage
      		fi
  	elif [ `expr match "$item" '-help'` != 0 ];then
  			usage
	else
            usage
	fi
done

echo_msg " "
pedigree-get-message.sh TSIN02108W
#echo_msg "WARNING: This script will drop the tables and recreate them. Please run it only on a fresh TS and fresh Pedigree installation"
continueOrExit

	echo_msg " "
	pedigree-get-message.sh TSIN02109I
	#echo_msg "----------Step 1 of 7 - Preparing System for running sample setup -----------"
	# Taking a backup of original pedigree.xml file created during installation.
	pedigree-get-message.sh TSIN02110I
	#echo_msg "Taking backup of original pedigree.xml" 
	 mv -f ${RFIDIC_HOME}/features/pedigree/pedigree.xml ${RFIDIC_HOME}/features/pedigree/pedigree.xml.$$
	
	pedigree-get-message.sh TSIN02112I
	#echo_msg "Deploying sample configuration and data"
	#Copying the pedigree.xml, pedigreeUI.properties etc from the pedigree folder to TS features folder
	${CP} -r ${RFIDIC_SOLDIR}/samples/epedigree/etc/* ${RFIDIC_HOME}/features/pedigree
			
	if [ -n "$was_admin_user" -a -n "$was_admin_password" ];then
		credentials="-was_admin_user=$was_admin_user -was_admin_password=$was_admin_password"
		wsadmin_creds="-conntype SOAP -user $was_admin_user -password $was_admin_password"
                tsar_credentials="-was_admin_user $was_admin_user -was_admin_password $was_admin_password"
	fi
	if [ -n "$was_runas_user" ];then
		was_runas="-was_runas_user=$was_runas_user"
	fi



	### TS Environment - both TS and Pedigree are on the same machine ###
	
	# Copying the sample etc, events, mdm from pedigree folder to rfidic pedigree folder

	echo_msg " "
	pedigree-get-message.sh TSIN02114I
	#echo_msg "----------Step 2 of 7 - Deploying Pedigree Metadata ---------------"
	

        $TS_HOME/bin/importReplaceTSAR.sh -file $TS_HOME/samples/epedigree/tsar/pedigree_sample.tsar -force $tsar_credentials

	pedigree-get-message.sh TSIN02115I
	#echo_msg "Stopping WAS"
	${TS_HOME}/bin/stopTS.sh $credentials -components=was,capture >> $LOG

	echo_msg " "
	pedigree-get-message.sh TSIN02118I
	#echo_msg "----------Step 3 of 7 - Importing Pedigree Master Data ---------------"

	#### load pedigree master data into the ITS repository ###
	pedigree-get-message.sh TSIN02119I
	#echo_msg "Importing Master Data - Standard Vocabulary"
	run_command ${RFIDIC_HOME}/bin/importMasterdata.sh $TS_HOME/samples/mdm/CoreBusinessVocabulary.xml >> $LOG
	pedigree-get-message.sh TSIN02122I
	#echo_msg "Importing Master Data - Contacts"
	run_command ${RFIDIC_HOME}/bin/importMasterdata.sh ${TS_HOME}/samples/epedigree/mdm/contacts.xml >> $LOG
	pedigree-get-message.sh TSIN02123I
	#echo_msg "Importing Master Data - Licenses"
	run_command ${RFIDIC_HOME}/bin/importMasterdata.sh ${TS_HOME}/samples/epedigree/mdm/licenses.xml >> $LOG
	pedigree-get-message.sh TSIN02124I
	#echo_msg "Importing Master Data - Locations"
	run_command ${RFIDIC_HOME}/bin/importMasterdata.sh ${TS_HOME}/samples/epedigree/mdm/locations.xml >> $LOG
	pedigree-get-message.sh TSIN02125I
	#echo_msg "Importing Master Data - Products"
	run_command ${RFIDIC_HOME}/bin/importMasterdata.sh ${TS_HOME}/samples/epedigree/mdm/products.xml >> $LOG
	pedigree-get-message.sh TSIN02126I
	#echo_msg "Importing Master Data - Partners"
	run_command ${RFIDIC_HOME}/bin/importMasterdata.sh ${TS_HOME}/samples/epedigree/mdm/partners.xml >> $LOG
	pedigree-get-message.sh TSIN02127I
	#echo_msg "Importing Master Data - Partners Private"
	run_command ${RFIDIC_HOME}/bin/importMasterdata.sh ${TS_HOME}/samples/epedigree/mdm/partnersPrivate.xml >> $LOG
	pedigree-get-message.sh TSIN02176I
	#echo_msg "Importing Master Data - Location Alternates"
	run_command ${RFIDIC_HOME}/bin/importMasterdata.sh ${TS_HOME}/samples/epedigree/mdm/locationAlternates.xml >> $LOG
	pedigree-get-message.sh TSIN02128I
	#echo_msg "Importing Master Data - Country Vocabulary"
	run_command ${RFIDIC_HOME}/bin/importMasterdata.sh ${TS_HOME}/samples/epedigree/mdm/countryVocabulary.xml >> $LOG
	pedigree-get-message.sh TSIN02129I
	#echo_msg "Importing Master Data - Region Vocubulary"
	run_command ${RFIDIC_HOME}/bin/importMasterdata.sh ${TS_HOME}/samples/epedigree/mdm/regionVocabularies.xml >> $LOG
	
	pedigree-get-message.sh TSIN02117I
	#echo_msg "Starting WAS"
	${TS_HOME}/bin/startTS.sh $was_runas $credentials >> $LOG

# none of this should be necessary.
	if /bin/false && [ -n "$was_admin_user" ];then
		# Add $was_admin_group to the following roles - SecurityRegistry, EPCISQuery
		RFAPP_NAME="com.ibm.rfidic.webEAR"
		pedigree-get-message.sh TSIN02130I $was_admin_group
		#echo_msg "Adding the $was_admin_group to roles SecurityRegistry of web EAR"
		run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $wsadmin_creds -f $RFIDIC_HOME/bin/jacl/addUsrOrGrpToSecurityRole.jacl $SERVERNAME $NODENAME $CELLNAME "$was_admin_group" "$RFAPP_NAME" "SecurityRegistry" "group" >> $LOG
		pedigree-get-message.sh TSIN02131I $was_admin_group
		#echo_msg "Adding the $was_admin_group to roles EPCISQuery of web EAR"
		run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $wsadmin_creds -f $RFIDIC_HOME/bin/jacl/addUsrOrGrpToSecurityRole.jacl $SERVERNAME $NODENAME $CELLNAME "$was_admin_group" "$RFAPP_NAME" "EPCISQuery" "group" >> $LOG
		
		RFAPP_NAME="com.ibm.epcis.pharma.pedigreeEAR"
		pedigree-get-message.sh TSIN02132I $was_admin_group
		#echo_msg "Adding the $was_admin_group to roles PedigreeService of Pedigree EAR"
		run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $wsadmin_creds -f $RFIDIC_HOME/bin/jacl/addUsrOrGrpToSecurityRole.jacl $SERVERNAME $NODENAME $CELLNAME "$was_admin_group" "$RFAPP_NAME" "PedigreeService" "group" >> $LOG
		pedigree-get-message.sh TSIN02133I $was_admin_group
		#echo_msg "Adding the $was_admin_group to roles TrackAndTrace of Pedigree EAR"
		run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $wsadmin_creds -f $RFIDIC_HOME/bin/jacl/addUsrOrGrpToSecurityRole.jacl $SERVERNAME $NODENAME $CELLNAME "$was_admin_group" "$RFAPP_NAME" "TrackAndTraceService" "group" >> $LOG
		RFAPP_NAME="DocumentPedigreeEAR"
		#echo_msg "Adding the $was_admin_group to roles HTTPCapture of DocumentPedigreeEAR EAR"
		run_command wsadmin.sh -wsadmin_classpath $CLASSPATH $wsadmin_creds -f $RFIDIC_HOME/bin/jacl/addUsrOrGrpToSecurityRole.jacl $SERVERNAME $NODENAME $CELLNAME "$was_admin_group" "$RFAPP_NAME" "HTTPCapture" "group" >> $LOG
		
		pedigree-get-message.sh TSIN02134I
		#echo_msg "Importing a security policy if was security is turned on for pedigree to work fine"		
		PATHTOFILE=com.ibm.ts.web/services/SecurityRegistryPort
	
		Policies_file="$PEDIGREE_HOME/etc/PEDIGREE_ImportPolicies.xml"
		# Replace the group in Policies_IVT.xml
		asciiUpdate "$Policies_file" '<userGroup>*.*</userGroup>' "<userGroup>$was_admin_group</userGroup>"
		SOAP=$PEDIGREE_HOME/etc/PEDIGREE_ImportPolicies.xml
		run_command $PEDIGREE_HOME/bin/callWebService.sh $credentials -path=$PATHTOFILE -soap=$SOAP

		run_command ${PEDIGREE_HOME}/bin/setPedWebServicesBindingInfoMain.sh $credentials
		

	fi


	### Putting events into queue ### 
	EVENT_PATH=${TS_HOME}/samples/epedigree/event
	sampleEPC="urn:epc:id:sgtin:0652642.107346.0001"
	case "$scenario" in
        EVENT)
			   echo_msg " "
			   #pedigree-get-message.sh TSIN02136I
			   echo_msg "---------- Step 4 of 6 - Sending sample events t1 and t2---------------"
		          run_command ${TS_HOME}/bin/submitEvent.sh -queue myeventq $EVENT_PATH/t1_commissioning.xml >> $LOG
		          run_command ${TS_HOME}/bin/submitEvent.sh -queue myeventq $EVENT_PATH/t2_shipping.xml >> $LOG
  		 	   sleep 10
			   echo_msg " "
			   #pedigree-get-message.sh TSIN02137I
			   echo_msg "---------- Step 5 of 6 - Sending sample events - t3 and t4 ----------"
			   run_command ${TS_HOME}/bin/submitEvent.sh -queue myeventq $EVENT_PATH/t3_receiving.xml >> $LOG
			   run_command ${TS_HOME}/bin/submitEvent.sh -queue myeventq $EVENT_PATH/t4_shipping.xml >> $LOG
            ;;
        DOCUMENT)
			   echo_msg " "
			   pedigree-get-message.sh TSIN02136I
			   #echo_msg "---------- Step 5 of 7 - Sending Sample Pedigree Document -sampleDoc.xml  ---------------"
		          run_command $RFIDIC_SOLDIR/bin/sendSamplePedigree.sh $RFIDIC_HOST $RFIDIC_PORT $RFIDIC_SOLDIR/samples/epedigree/doc/sampleDoc.xml $was_admin_user $was_admin_password >> $LOG
  		 	   sleep 10
			   echo_msg " "
			   pedigree-get-message.sh TSIN02137I
			   #echo_msg "---------- Step 6 of 7 - Sending sample events - t3 and t4 ----------"
			   run_command ${TS_HOME}/bin/submitEvent.sh -queue myeventq $EVENT_PATH/t3_receiving.xml >> $LOG
			   run_command ${TS_HOME}/bin/submitEvent.sh -queue myeventq $EVENT_PATH/t4_shipping.xml >> $LOG
	esac

index=0
echo_msg " "
pedigree-get-message.sh TSIN02139I
#echo_msg "---------- Step 7 of 7 - Verifying Pedigree --------- "
pedigree-get-message.sh TSIN02140I $sampleEPC $scenario
#echo_msg " Invoking periodically to allow time for events to settle in $sampleEPC $scenario"
while [ "$index" -lt "10" ]
        do
               sleep 5 
               index=`expr $index + 1`
               pedigree-get-message.sh TSIN02141I $index
               #echo_msg "Trial No - $index"
			   ### Verifying Pedigree Generation (GetPedigree)###
				if [ -n "$was_admin_user" -a -n "$was_admin_password" ]
				then
					#PATHTOFILE=com.ibm.epcis.pedigree.ws/services/PedigreeServicePort
					#SOAP=$PEDIGREE_HOME/bin/VerifyPedigreeSOAP.xml
					#run_command webserviceCall $PATHTOFILE $SOAP
					${TS_HOME}/bin/verifyPedigree.sh https://$RFIDIC_HOST:$RFIDIC_PORT $sampleEPC $scenario $was_admin_user $was_admin_password  >> $LOG
				else
   				   ${TS_HOME}/bin/verifyPedigree.sh http://$RFIDIC_HOST:$RFIDIC_PORT $sampleEPC  $scenario >> $LOG
				fi
			   # The epc was taken from t1_commissioning.xml
			   if [ $? -eq 0 ];then
			    pedigree-get-message.sh TSIN02142I
				#echo_msg "------ Pedigree Verification Successful ------"
				pedigree-get-message.sh TSIN02143I
				#echo_msg "Please check the setupSample.log for details"
				pedigree-get-message.sh TSIN02142I
				#echo_msg "------ Pedigree Verification Successful ------"
			    index=100
			   fi
        done
mv -f ${TS_HOME}/features/pedigree/pedigree.xml.$$ ${TS_HOME}/features/pedigree/pedigree.xml >> $LOG
if [ "$index" -ne "100" ]; then
				pedigree-get-message.sh TSIN02144I
				#echo_msg "------ Pedigree Verification FAILED ------"
				pedigree-get-message.sh TSIN02143I
				#echo_msg "Please check the setupSample.log for details"
				pedigree-get-message.sh TSIN02144I
				#echo_msg "------ Pedigree Verification FAILED ------"
  exit 1
fi
exit 0
